<?php
/*+***********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.1
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is: vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 *************************************************************************************/
$languageStrings = array(

	// Footer
	'APPTITLE' => 'vtiger CRM',
	'POWEREDBY'=> 'Powered by vtiger CRM',
	'LBL_READ_LICENSE' => 'Read License',
	'LBL_PRIVACY_POLICY' => 'Privacy Policy',

	// Common Actions
	'LBL_SELECT_ALL' => 'تحديد الكل',
	'LBL_SELECT_TO_LOAD_LIST' => 'اختر لتحميل القائمة',
	'LBL_CREATING_NEW' => 'انشاء جديد',
	'LBL_EDITING' => 'تعديل',
	'LBL_SAVE' => 'حفظ',
	'LBL_CANCEL' => 'الغاء',
	'LBL_BACK' => 'السابق',
	'LBL_IMPORT' => 'استيراد',
	'LBL_EXPORT' => 'تصدير',
	'LBL_FIND_DUPLICATES' => 'البحث عن تكرار',
	'LBL_MORE' => 'المزيد',
	'LBL_ACTIONS' => 'تاثير',
    'LBL_ADD' => 'اضافة',
	'LBL_EDIT' => 'تعديل',
	'LBL_DELETE' => 'حذف',
	'LBL_SETTINGS'=> 'اعدادات',
	'LBL_ADD_COMMENT' => 'اضافة تعليق',
	'LBL_EDIT_FIELDS' => 'الحقول٪s ق وتخطيط',
	'LBL_EDIT_WORKFLOWS' => 'مهام سير العمل ٪s الصورة',
	'LBL_EDIT_PICKLIST_VALUES' => 'Picklists القيم',
	'LBL_EDIT_MAILSCANNER' => 'تحويل البريد',
	'LBL_RECORD_DELETE' => 'التسجيل الذي تحاول عرضه قد تم شطبه',
	'LBL_RECORD_NOT_FOUND' => 'التسجيل الذي تحاول الوصول اليه غير موجود',
	'LBL_EDIT_REASON' => 'تعديل السبب',

	//'LBL_EDIT_CURRENT_FILTER' => 'تعديل اللائحة الحالي',
	//'LBL_DELETE_CURRENT_FILTER' => 'شطب اللائحة الحالي',
	'LBL_SELECT' => 'تحديد',
	'LBL_CLEAR' => 'مسح',
	'LBL_YES' => 'نعم',
	'LBL_NO' => 'لا',
	'LBL_SHOW_COMPLETE_DETAILS' => 'اكمال التفاصيل',
    'LBL_MASS_EDITING' => 'تعديل جماعي',
	'LBL_DESELECT_ALL_RECORDS' => 'إلغاء جميع',
	'LBL_QUICK_CREATE' => 'إنشاء سريعة',
	'LBL_SEND_EMAIL' => 'ارسال بريد الكتروني',
	//SEND EMAIL translations
	'LBL_ALL_EMAILS' => 'البريد الالكتروني لجميع جهات الاتصال',
	'LBL_MUTIPLE_EMAIL_SELECT_ONE' => 'هذا السجل يخزن حسابات البريد الالكتروني‫.‬ الرجاء اختر الحسابات لتحديد اي بريد الكتروني سيرسل اليه',
	//SEND EMAIL translations
	'LBL_GO_TO_FULL_FORM' => 'الذهاب الى القالب الكامل',
	'LBL_SEND_SMS' => 'ارسال رسالة نصية',
	'LBL_FOUND' => 'موجود',
	'LBL_CLICK_ADD' => 'اانقر لإضافة',
	'LBL_ADD_MORE_FIELDS' => 'اضافة حقول اخرى',
	'LBL_ADD_NOTE' => 'اضافة وثيقة',
	'LBL_CREATE_NEW' => 'انشاء جديد',
    'LBL_ADD_EVENT' => 'اضافة حدث',
    'LBL_ADD_TASK' => 'إضافة مهمة',
	'LBL_MARKETING_AND_SALES' => 'التسويق و المبيعات',
	'LBL_TOOLS_HEADER' => 'ادوات',
	'LBL_SUPPORT' => 'الدعم',
	'LBL_INVENTORY' => 'الجرد',
	'LBL_ANALYTICS' => 'التحليل',
	'LBL_HOME' => 'الرئيسية',

	// Common Link Labels
	'LBL_LAST_VIEWED_RECORDS' => 'اخر الحقول المشاهدة',
	'LBL_DASHBOARD' => 'لوحة الحركات',
	'LBL_USER_SETTINGS' => 'اعدادات المستخدم',
	'LBL_MY_PREFERENCES' => 'الخيارات',
	'LBL_SIGN_OUT' => 'تسجيل الخروج',
	'LBL_HELP' => 'مساعدة',
	'LBL_DOCUMENTATION' => 'الوثائق',
	'LBL_VIDEO_TUTORIAL' => 'فيديو تعليمي',
	'LBL_FEEDBACK' => 'الانطباع المتروك',
	'LBL_CHAT_SUPPORT'=>'دعم الدردشة',
	'LBL_CRM_SETTINGS' => 'CRM اعدادات',
	'LBL_ON_DEMAND_ADMIN' => 'اضافة \ حذف المستخدمين',
	'LBL_ANNOUNCEMENT' => 'اعلان',
	'LBL_CALENDAR' => 'مفكرة',
	'LBL_POST' => 'ارسال',
	'LBL_GUIDER' => 'الهادي',
	'LBL_DISPLAY_TYPE' => 'عرض النوع',
	'LBL_DISPLAY_WIDETYPE' => 'واسع',
	'LBL_DISPLAY_MEDIUMTYPE' => 'متوسط',
	'LBL_DISPLAY_NARROWTYPE' => 'ضيق',
	'LBL_TAG_THIS_RECORD' => 'تحديد علامة لهذا السجل',
	'LBL_PAGE' => 'Page',
	'LBL_LISTVIEW_PAGE_JUMP' => 'القفز للصفحة',
	'LBL_PROFILE_PASSWORD' => 'الملف الشخصي / كلمة المرور',

	// Common Fields
	'LBL_USER' => 'المستخدم',
	'LBL_GROUP' => 'المجموعة',
	'Last Modified By' => 'التعديل الاخير من قبل',
	'Created Time' => 'وقت الانشاء',
	'Modified Time' => 'وقت التعديل',
	'Description' => 'الوصف',
	'Assigned To'=>'تعيين ل',

	//Loading Labels
	'LBL_LOADING' => 'تحميل',
	'LBL_LOADING_WIDGET' => 'تحميل القطعة',
	'LBL_LOADING_LISTVIEW_CONTENTS'	=> 'جاري التحميل ‫..‬ الرجاء الانتظار',

	// Detail View
	'LBL_UPDATES' => 'تحديثات',
	'LBL_SHOW_FULL_DETAILS' => 'اظهار التفاصيل الكاملة',
	'LBL_SUMMARY_DETAILS' => 'ملخص التفاصيل',
	'LBL_ADD_NEW_COMMENT' =>'اضافة تعليق جديد',
	'LBL_NO_UPDATES' => 'لايوجد تحديثات',
	'LBL_ACTIVITIES' => 'النشاطات',
	'LBL_NO_PENDING_ACTIVITIES' => 'لا توجد انشطة في الانتظار',
	'LBL_SUMMARY' => 'الملخص',
	'LBL_DETAILS' => 'التفاصيل',

	// Popup window
	'LBL_SEARCH_FOR' => 'البحث عن',
	'LBL_IN' => 'في',
	'LBL_TYPE_SEARCH' => 'اكتب للبحث',
	'LBL_SEARCH_BUTTON' => 'زر البحث',
	'LBL_ADVANCE_SEARCH' => 'بحث متقدم',
	'LBL_LOADING_PLEASE_WAIT' => 'جاري التحميل، الرجاء الانتظار.',
	'LBL_PLEASE_SELECT_MODULE' => 'الرجاء اختيار الموديل',

	//DropDown Category
	'LBL_USERS' => 'المستخدمين',
	'LBL_GROUPS' => 'المجموعات',

	//EditView Form Links
	'LBL_FULL_FORM' => 'النموذج الكامل',
	'LBL_SIMPLE_FORM' => 'النموذج البسيط',

	//Recent Comments
	'LBL_ADD_YOUR_COMMENT_HERE' => 'اضف تعليقك هنا',
	'LBL_REASON_FOR_CHANGING_COMMENT' => 'سبب تغير التعليق',
	'LBL_REPLY' => 'Reply',
	'LBL_VIEW_THREAD' => 'عرض الموضوع',
	'LBL_NO_COMMENTS' => 'لايوجد تعليقات',
	'LBL_REPLIES' => 'ردود',
	'LBL_REPLY_ALL' => 'الرد على الكل',

	//Translation for all modules
	'Accounts' => 'المنظمات',
	'Assets' => 'الاصول',
	'Calendar' => 'المفكرة',
	'Campaigns' => 'الحملات',
	'Contacts' => 'جهات الاتصال',
	'Documents' => 'المستندات',
	'Leads' => 'الزبون المحتمل',
	'ModComments' => 'التعليقات',
	'Potentials' => 'الفرص',
	'PriceBooks' => 'كتاب الاسعار',
	'Products' => 'المنتجات',
	'Project' => 'المشاريع',
	'ProjectMilestone' => 'احداث المشاريع',
	'ProjectTask' => 'مهام المشاريع',
	'ServiceContracts' => 'عقود الخدمات',
	'Services' => 'الخدمات',
	'Vendors' => 'الموردين',
	'Rss' => 'RSS',
	'Quotes'=>'العروض',
	'PurchaseOrder'=>'أوامر الشراء',
	'SalesOrder'=>'أوامر البيع',
	'Invoice'=>'الفواتير',
	'MailManager' => 'التحكم بالبريد',
        'Portal' => 'مواقعنا',
        'Print Templates' => 'طباعة قالب',
        'RecycleBin' => 'سلة المحذوفات',
        'Email Templates' => 'Email Template',


	//Basic String Translation
	'LBL_ADD_RECORD' => 'اضافة تسجيل',
	'LBL_RECENTLY_MODIFIED' => 'تم تعديلها مؤخرا',
	'LBL_RECORDS_LIST' => 'قائمة التسجيلات',
	'LBL_RECORD_SUMMARY' => 'ملخص الموديل',
	'LBL_RECORD_SUMMARY' => 'تفاصيل الموديل',
	'LBL_ACCESS_DENIED_FOR' => 'تم رفض الوصول ل',
	'LBL_GO_BACK' => 'العودة',
	'LBL_NO_DATA_AVAILABLE' => 'لا توجد بيانات متاحة',

	// Global Search
	'LBL_GLOBAL_SEARCH' => 'اكتب الكلمة و اضغط دخول',
	'LBL_ALL_RECORDS' => 'جميع السجلات',
	'LBL_NO_RECORDS_FOUND' => 'لا يوجد سجلات',

	//Filters & Advance Filter
	'LBL_AND' => 'و',
	'LBL_OR' => 'او',
	'LBL_NONE' => 'لاشئ',
	'LBL_APPROVE' => 'موافق عليه',
	'LBL_HAS_CHANGED' => 'تغير',
	'LBL_HAS_CHANGED_TO' => 'تغيرت ل',
	'LBL_HAS_CHANGED_FROM' => 'قد تغير من',
	'LBL_LESS_THAN_OR_EQUAL_TO' => 'اقل او يساوي',
	'LBL_GREATER_THAN_OR_EQUAL_TO' => 'أكبر من أو يساوي',
	'LBL_IS_NOT' => 'ليس',
	'LBL_IS_ADDED' => 'يضاف',
	'LBL_IS_TODAY' => 'اليوم',
	'LBL_IS_TOMORROW' => 'غدا',
	'LBL_IS_YESTERDAY' => 'هو أمس',
	'LBL_LESS_THAN_DAYS_LATER' => 'بعد أقل من يوم',
	'LBL_MORE_THAN_DAYS_LATER' => 'بعد مرور أكثر من أيام',
	'LBL_DENY' => 'مرفوض',
	'LBL_EQUALS' => 'يساوي',
	'LBL_NOT_EQUAL_TO' => 'لا يساوي',
	'LBL_STARTS_WITH' => 'يبدء ب',
	'LBL_ENDS_WITH' => 'ينتهي ب',
	'LBL_CONTAINS' => 'يحتوي على',
	'LBL_DOES_NOT_CONTAIN' => 'لا يحتوي على',
	'LBL_LESS_THAN' => 'اقل من',
	'LBL_GREATER_THAN' => 'اكبر من',
	'LBL_LESS_THAN_OR_EQUAL' => 'اقل او يساوي',
	'LBL_GREATER_OR_EQUAL' => 'اكبر او يساوي',
	'LBL_BEFORE' => 'قبل',
	'LBL_AFTER' => 'بعد',
	'LBL_BETWEEN' => 'بين',
	'LBL_SEARCH' => 'بحث',
	'LBL_SEARCH_IN' => 'بحث في',
	'LBL_ADD_CONDITION' => 'اضافة شرط',
	'LBL_ADD_GROUP' => 'اضافة مجموعة شروط',
	'LBL_FILTER_CONDITIONS' => 'قائمة الاحكام',
	'LBL_ALL_CONDITIONS' => 'جميع الشروط',
	'LBL_ALL_CONDITIONS_DESC' => 'جميع الشروط يجب ان تتحقق',
	'LBL_ANY_CONDITIONS' => 'اي شرط ',
	'LBL_ANY_CONDITIONS_DESC' => 'على الاقل واحد من الشروط يجب ان يتحقق',
	'LBL_SELECT_FIELD' => 'حدد الحقل',
	'LBL_SELECT_MODULE' => 'حدد الموديل',
	'LBL_CREATE_NEW_FILTER' => 'إنشاء قائمة جديدة',
	'All' => 'كل',
	'Others' => 'اخرى',
	'Pending' => 'معلق',
	'Public' => 'عام',

	//Advance Search
	'LBL_SAVE_FILTER' => 'حفظ قائمة',
	'LBL_SAVE_MODIFY_FILTER' => 'حفظ / تعديل قائمة',
	'LBL_SEARCH_RESULTS' => 'نتائج البحث',
	'LBL_SAVE_AS_FILTER' => 'حفظ باسم قائمة',

	//Exception String Translation
	'LBL_NOT_ACCESSIBLE' => 'تعذر الوصول',

	//Line Items
	'LBL_ITEM_DETAILS'=> 'تفاصيل البند',
	'LBL_CURRENCY' => 'العملة',
	'LBL_TAX_MODE' => 'طريقة الضريبة',
	'LBL_INDIVIDUAL' => 'فردي',
	'LBL_GROUP' => 'مجموعة',
	'LBL_TOOLS' => 'الادوات',
	'LBL_ITEM_NAME' => 'اسم البند',
	'LBL_QTY_IN_STOCK' => 'المخزن',
	'LBL_QTY' => 'الكمية',
	'LBL_LIST_PRICE' => 'قائمة الاسعار',
	'LBL_TOTAL' => 'المجموع',
	'LBL_NET_PRICE' => 'صافي السعر',
	'LBL_DISCOUNT' => 'الخصم',
	'LBL_TOTAL_AFTER_DISCOUNT' => 'الاجمالي بعد الخصم',
	'LBL_TAX' => 'ضريبة',
	'LBL_ADD_PRODUCT' => 'اضافة منتج',
	'LBL_ADD_SERVICE' => 'اضافة خدمة',
	'LBL_ITEMS_TOTAL' => 'مجموع البنود',
	'LBL_SHIPPING_AND_HANDLING_CHARGES' => 'رسوم الشحن والمناولة',
	'LBL_PRE_TAX_TOTAL' => 'مجموع الضرائب',
	'LBL_TAX_FOR_SHIPPING_AND_HANDLING' => 'ضرائب الشحن والمناولة',
	'LBL_SET_SHIPPING_AND_HANDLING_TAXES_FOR' => 'تعين ضريبة الشحن والمناولة ل',
	'LBL_ADJUSTMENT' => 'تسوية',
	'LBL_DEDUCT' => 'حسم',
	'LBL_GRAND_TOTAL' => 'المجموع الكلي',
	'LBL_ZERO_DISCOUNT' => 'بدون خصم',
	'LBL_OF_PRICE' => 'السعر',
	'LBL_DIRECT_PRICE_REDUCTION' => 'تخفيض السعر المباشر',
	'LBL_SET_DISCOUNT_FOR' => 'تعين خصم ل',
	'LBL_STOCK_NOT_ENOUGH' => 'غير كافي بالمخزن',
	'LBL_MAX_QTY_SELECT' => 'القيمة القصوى هي',
	'LBL_DRAG' => 'سحب',
	'LBL_TOTAL_TAX_AMOUNT' => 'المبلغ الكلي للضرائب',
	'LBL_DIRECT_AMOUNT_DISCOUNT' => 'مبلغ الخصم المباشر',
	'LBL_FINAL_DISCOUNT_AMOUNT' => 'مبلغ الخصم النهائي',
	'LBL_MORE_CURRENCIES' => 'عملات اخرى',
	'LBL_SET_TAX_FOR' => 'تعيين ضريبة ل',
	'LBL_GROUP_TAX' => 'ضريبة المجموعة',
	'LBL_BILLING_ADDRESS_FROM' => 'نسخ عنوان الدفع من',
	'LBL_SHIPPING_ADDRESS_FROM' => 'نسخ عنوان الشحن من',
	'LBL_COPY_SHIPPING_ADDRESS' => 'عنوان الشحن',
	'LBL_COPY_BILLING_ADDRESS' => 'عنوان الدفع',
	'LBL_OVERALL_DISCOUNT' => 'خصم الشاملة',
	'LBL_CHARGES' => 'الرسوم',
	'LBL_CHARGES_TOTAL' => 'رسوم الإجمالي',
	'LBL_TAXES_ON_CHARGES' => 'الضرائب على الرسوم',
	'LBL_DEDUCTED_TAXES' => 'الضرائب Deducted',
	'LBL_DEDUCTED_TAXES_TOTAL' => 'الضرائب Deducted إجمالي',
	'LBL_DEFAULT' => 'الافتراضي',
	'LBL_ITEM' => 'بند',

	//DetailView Actions
	'LBL_CREATE' => 'انشاء',
	'LBL_GENERATE' => 'توليد',
    'LBL_DUPLICATE' => 'تكرار',
	'Add Note' => 'اضافة مستند',

	//Dashboard String
	'LBL_ADD_WIDGET' => 'اضافة قطعة',
	'LBL_COMMENTS' => 'تعليقات',
	'LBL_REFRESH' => 'تحديث',
	'LBL_CLOSE' => 'اغلاق',
	'LBL_ALL' => 'الكل',
	'LBL_UPDATED' => 'تحديث',
	'LBL_FROM' => 'من',
	'LBL_TO' => 'الى',
	'LBL_to' => 'الى',
	'LBL_ON' => 'على',
	'LBL_OF' => 'من',
	'LBL_BY' => 'من قبل',
	'LBL_ADDED' => 'اضيف',
	'LBL_FOR' => 'ل',
	'LBL_CREATED' => 'انشئ',
	'LBL_DELETED' => 'الغي',
	'LBL_RESTORED' => 'معاد',
	'LBL_COMMENTED' => 'علق',
	'LBL_REMOVED' => 'ازيل',
	'LBL_REMOVE' => 'ازالة',
	'LBL_AT' => 'في',
	'LBL_MINE' => 'لي',
	'History' => 'ارشيف',
	'Upcoming Tasks' => 'المهام القادمة',
	'LBL_YEAR' => 'سنة',
	'LBL_YEARS' => 'سنوات',
	'LBL_MONTH' => 'شهر',
	'LBL_MONTHS' => 'اشهر',
	'LBL_DAY' => 'يوم',
	'LBL_DAYS' => 'ايام',
	'LBL_HOUR' => 'ساعة',
	'LBL_HOURS' => 'ساعات',
	'LBL_MINUTE' => 'دقيقة',
	'LBL_MINUTES' => 'دقائق',
	'LBL_SECOND' => 'ثانية',
	'LBL_SECONDS' => 'ثواني',
	'LBL_JUSTNOW' => 'الان',
	'LBL_CUSTOM_INFORMATION' => 'المعلومات المخصصة',
	'LBL_NO_RECENT_UPDATES' => 'لا يوجد تحديثات',
	'LBL_NO_DATA' => 'لا توجد بيانات',
	'LBL_PERMISSION_DENIED' => 'تعذر في الوصول',
	'LBL_HANDLER_NOT_FOUND' => 'لم يتم العثور على المعالج',
	'LBL_FILTER' => 'لائحة',
	'LBL_DUE' => 'يرجع الى',
	'LBL_DAYS' => 'ايام',
	'LBL_COMPLETED' => 'منتهى',
	'LBL_AGO' => 'منذ',
	'LBL_CHANGED' => 'تغيير',
	'Single_Users' => 'مستخدم',
	'LBL_MATCHED_THIS_CRITERIA'=> 'يقابل هذه المعاير',
	'LBL_NO_SCHEDULED_ACTIVITIES' => 'لايوجد انشطة مقررة',
	'LBL_NO_OVERDUE_ACTIVITIES' => 'لايوجد انشطة متاخرة',
	'LBL_NO_UPDATES_OR_COMMENTS' => 'لايوجد تحديثات او تعليقات',
	'LBL_MINI_LIST' => 'قائمة مصغرة',
	'LBL_NOTEPAD' => 'المفكرة',
	'LBL_NOTEPAD_NAME' => 'اسم المفكرة',
	'LBL_NOTEPAD_CONTENT' => 'محتوى المفكرة',
	'LBL_LAST_SAVED_ON' => 'اخر حفظ بتاريخ',
	'Mini List' => 'قائمة مصغرة',
	'Notebook' => 'مفكرة',
	'LBL_RESULT_FOR_THE_TAG' => 'نتائج العلامات',
        'LBL_ALL_USERS' => 'جميع الاعضاء',
        'LBL_BOTH' => 'كلا',
        'LBL_SHOW' => 'عرض',
	'LBL_SELECT_DATE_RANGE' => 'حدد نطاق تاريخ',

	// Basic Strings- custom view
	'LBL_VIEW_NAME' => 'قائمة الاسم',
	'LBL_CREATE_VIEW' => 'انشاء معاينة جديدة',
	'LBL_BASIC_DETAILS' => 'التفاصيل الاساسية',
	'LBL_CHOOSE_COLUMNS' => 'اختيار الاعمدة و الترتيب',
	'LBL_MAX_NUMBER_FILTER_COLUMNS' => 'الاقصى ١٥',
	'LBL_FILTER_ON_DATE' => 'لائحة حسب التسجيل',
	'LBL_CHOOSE_FILTER_CONDITIONS' => 'اختيار شروط اللائحة',
	'LBL_ADD_CONDITION' => 'اضافة شروط',
	'LBL_SET_AS_DEFAULT' => 'تعيين كافتراضي',
	'LBL_LIST_IN_METRICS' => 'قائمة في المقاييس',
	'LBL_SET_AS_PUBLIC' => ' تعيين كعام',
	'LBL_AND' => 'و',
	'LBL_OR' => 'او',
	'LBL_ADD_MORE_COLUMNS' => 'انقر لتحديد الحقول',
	'LBL_ADD_GROUP' => 'اضافة مجموعة',


	//DateFilter Conditions
	'LBL_CUSTOM' => 'Custom',
	'LBL_PREVIOUS_FY' => 'Previous FY',
	'LBL_CURRENT_FY' => 'Current FY',
	'LBL_NEXT_FY' => 'Next FY',
	'LBL_PREVIOUS_FQ' => 'Previous FQ',
	'LBL_CURRENT_FQ' => 'Current FQ',
	'LBL_NEXT_FQ' => 'Next FQ',
	'LBL_YESTERDAY' => 'Yesterday',
	'LBL_TODAY' => 'Today',
	'LBL_TOMORROW' => 'Tomorrow',
	'LBL_LAST_WEEK' => 'Previous Week',
	'LBL_CURRENT_WEEK' => 'Current Week',
	'LBL_NEXT_WEEK' => 'Next Week',
	'LBL_LAST_MONTH' => 'Previous Month',
	'LBL_CURRENT_MONTH' => 'Current Month',
	'LBL_NEXT_MONTH' => 'Next Month',
	'LBL_LAST_7_DAYS' => 'Last 7 Days',
	'LBL_LAST_14_DAYS' => 'Last 14 Days',
	'LBL_LAST_30_DAYS' => 'Last 30 Days',
	'LBL_LAST_60_DAYS' => 'Last 60 Days',
	'LBL_LAST_90_DAYS' => 'Last 90 Days',
	'LBL_LAST_120_DAYS' => 'Last 120 Days',
	'LBL_NEXT_7_DAYS' => 'Next 7 Days',
	'LBL_NEXT_14_DAYS' => 'Next 14 Days',
	'LBL_NEXT_30_DAYS' => 'Next 30 Days',
	'LBL_NEXT_60_DAYS' => 'Next 60 Days',
	'LBL_NEXT_90_DAYS' => 'Next 90 Days',
	'LBL_NEXT_120_DAYS' => 'Next 120 Days',

	//advanced Filter Options
	'LBL_EQUALS' => 'يساوي',
	'LBL_NOT_EQUAL_TO' => 'لا يساوي',
	'LBL_STARTS_WITH' => 'يبدء ب',
	'LBL_ENDS_WITH' => 'ينتهي ب',
	'LBL_CONTAINS' => 'يحتوي على',
	'LBL_DOES_NOT_CONTAIN' => 'لايحتوي على',
	'LBL_LESS_THAN' => 'اقل من',
	'LBL_GREATER_THAN' => 'اكبر من',
	'LBL_LESS_THAN_OR_EQUAL' => 'اقل او يساوي',
	'LBL_GREATER_OR_EQUAL' => 'اكبر او يساوي',
	'LBL_BEFORE' => 'قبل',
	'LBL_AFTER' => 'بعد',
	'LBL_BETWEEN' => 'بين',
	'LBL_IS_EMPTY'=> 'فارغ',
    'LBL_IS_NOT_EMPTY' => 'ليس فارغا',

	//Detail view summary widgets
	'LBL_OWNER' => 'مالك',
	'LBL_CREATED_ON' => 'تم انشائه في',
	'LBL_MODIFIED_ON' => 'تم التعديل في',
	'LBL_MODIFIED' => 'تم التعديل',
	'LBL_COMMENTED' => 'علق',

    //calender set-reminder
    'LBL_BEFORE_EVENT' => ' قبل الحدث',

	//Dashboard widgets
	'History' => 'الارشيف',
	'Upcoming Activities' => 'الانشطة القادمة',
	'Overdue Activities' => 'الانشطة المتاخرة',
	'Funnel' => 'مركز',
	'Potentials by Stage' => 'الفرص من خلال المرحلة',
	'Pipelined Amount' => 'مخطط المبيعات',
	'Total Revenue' => 'اجمالي الايرادات',
	'Top Potentials' => 'اعلى الفرص',
	'Forecast' => 'توقعات',
	'Leads Created' => 'الزبائن المتوقعين',
	'Leads by Status' => 'الزبائن المتوقعين حسب الحالة',
	'Leads by Source' => 'الزبائن المتوقعين حسب المصدر',
	'Leads by Industry' => 'الزبائن المتوقعين حسب القطاع',
	'Tickets by Status' => 'التذاكر حسب الحالة',
	'Open Tickets' => 'التذاكر المفتوحة',
	'Funnel Amount' => 'مجموع المبلغ من قبل مرحلة المبيعات',

	//Exports strings
	'LBL_EXPORT_ALL_DATA' => 'تصدير جميع البيانات',
	'LBL_EXPORT_DATA_IN_CURRENT_PAGE' => 'تصدير بيانات الصفحة الحالية',
	'LBL_EXPORT_SELECTED_RECORDS' => 'تصدير السجلات المحددة',
	'LBL_EXPORT_RECORDS' => 'تصدير السجلات',
	'LBL_NO_RECORD_SELECTED' => 'لايوجد سجلات مختارة.',
	'LBL_CAN_NOT_REMOVE_DEFAULT_WIDGET' => 'لايمكن ازالة القطعة الافتراضية',
	'LBL_CUSTOM_VIEW_NAME_DUPLICATES_EXIST' => 'اللائحة موجود مسبقا',
        'LBL_EXPORT_CURRENCY_TOOLTIP_TEXT'=>'قيم العملات في خط لتصدير العناصر، وسوف vtiger إدارة استخدام هذا الإعداد لتصدير العملة لأن هذا. أي قيم العملات خارج بنود الجداول، وسيكون للمستخدمين في تصدير كعملة المفضل ( مختارة في بلدي تفضيلات )',
        'LBL_EXPORT_LINEITEM_CURRENCY'=>'اختيار العملة ( لاين القيم الإغلاق )',
        'LBL_EXPORT_USER_CURRENCY' =>'بلدي المفضل العملات',
        'LBL_EXPORT_RECORD_CURRENCY'=>'العملة المحددة في سجل',
	'LBL_EXPORT_FORMAT' => 'تنسيق التصدير',
	'LBL_EXPORT_DATA' => 'بيانات التصدير',
    
	'LBL_ADD_MANAGE_MODULES' => 'إضافة / التحكم بالموديلات',

	// Added Common Keys for all modules
	'Account Name' => 'اسم المنظمة',
	'Add Comment' => 'اضافة تعليق',
	'Adjustment' => 'تعديل',
	'Annual Revenue' => 'الايرادات السنوية',
	'Apparel'=>'حلة',
	'Banking'=>'مصرفي',
	'Billing Address' => 'عنوان الدفع',
	'Billing City' => 'مدينة الدفع',
	'Billing Code' => 'كود الدفع',
	'Billing Country' => 'دولة الدفع',
	'Billing Po Box' => 'صندوق بريد الدفع',
	'Billing State' => 'ولاية الدفع',
	'Biotechnology'=>'التكنولوجيا الحيوية',

	//for SO PO and Quotes
	'FedEx'=>'FedEx',
	'UPS'=>'UPS',
	'USPS'=>'USPS',
	'DHL'=>'DHL',
	'BlueDart'=>'BlueDart',
	'Carrier' => 'الناقل',
	'Category'=>'فئة',
	'Chemicals'=>'كيميائي',
	'City' => 'المدينة',

	'Cold Call'=>'اتصال فاتر',
	'Existing Customer'=>'زبون حالي',
	'Self Generated'=>'مولد ذاتي',
	'Employee'=>'موظف',
	'Partner'=>'شريك',
	'Public Relations'=>'علاقات عامة',
	'Direct Mail'=>'البريد المباشر',
	'Conference'=>'مؤتمر',
	'Trade Show'=>'صالة عرض',
	'Web Site'=>'الموقع الالكتروني',
	'Word of mouth'=>'كلام متناقل',
	'Other'=>'اخرى',

	//for leads and accounts
	'--None--'=>'--لاشيء--',
	'Acquired'=>'مكتسب',
	'Active'=>'نشيط',
	'Market Failed'=>'فشل السوق',
	'Project Cancelled'=>'مشروع ملغي',
	'Shutdown'=>'مغلق',
	'Apparel'=>'حلة',
	'Banking'=>'مصرفي',
	'Biotechnology'=>'تكنولوجيا حيوية',
	'Chemicals'=>'كيميائي',
	'Communications'=>'اتصالات',
	'Construction'=>'معماري',
	'Consulting'=>'استشارات',
	'Education'=>'تعليم',
	'Electronics'=>'الكترونيات',
	'Energy'=>'طاقة',
	'Engineering'=>'هندسة',
	'Entertainment'=>'حفلات',
	'Environmental'=>'بيئي',
	'Finance'=>'تمويل',
	'Food & Beverage'=>'ماكولات و مشروبات',
	'Government'=>'حكومي',
	'Healthcare'=>'العناية بالصحة',
	'Hospitality'=>'مستشفى',
	'Insurance'=>'تامين',
	'Machinery'=>'مكائن',
	'Manufacturing'=>'صناعي',
	'Media'=>'اعلام',
	'Not For Profit'=>'غير ربحية',
	'Recreation'=>'استجمام',
	'Retail'=>'تجزءة',
	'Shipping'=>'شحن',
	'Technology'=>'تكنولوجيا',
	'Telecommunications'=>'اتصالات',
	'Transportation'=>'نقل',
	'Utilities'=>'معدات',

	'Contact Name' => 'اسم جهة الاتصال',
	'Conversion Rate' => 'معدل التحويل',

	'Shipping Address' => 'عنوان الشحن',
	'Shipping City' => 'مدينة الشحن',
	'Shipping State' => 'ولاية الشحن',
	'Shipping Code' => 'كود الشحن',
	'Shipping Country' => 'دولة الشحن',
	'Shipping Po Box' => 'صندوق بريد الشحن',
	'Country' => 'الدولة',
	'Description' => 'الوصف',

	'Created'=>'انشئ',
	'Approved'=>'موافق عليه',
	'Delivered'=>'تم التسليم',
	'Cancelled'=>'الغي',

	'Currency' => 'العملة',
	'LBL_BASE_CURRENCY' => 'افتراضي العملات',

	'Discount Percent' => 'نسبة الخصم',
	'Discount Amount' => 'مقدار الخصم',
	'Item Discount Amount' => 'مبلغ خصم البند',
	'Item Discount Percent' => 'نسبة خصم البند',

	'Due Date' => 'تاريخ الاستحقاق',
	'Due Date & Time' => 'تاريخ و وقت الاستحقاق',
	'Email Opt Out' => 'انسحاب البريد الالكتروني',
    'Is Converted From Lead' => 'يتم تحويلها من الرصاص' , 

	'Expected Close Date' => 'تاريخ الاغلاق المتوقع',

	'Fax' => 'فاكس',

	'Last Name' => 'اسم العائلة',
	'First Name' => 'الاسم الاول',

	'High' => 'مرتفع',
	'Low' => 'منخفض',

	'In Progress' => 'في المعالجة',


	'Subject' => 'الموضوع',
	'Shipping Address'=>'عنوان الشحن',
	'Shipping Po Box'=>'صندوق بريد الشحن',
	'Shipping City'=>'مدينة الشحن',
	'Shipping State'=>'ولاية الشحن',
	'Shipping Code'=>'كود الشحن',
	'Shipping Country'=>'دولة الشحن',
	'Terms & Conditions' => 'الشروط و الاحكام',
	'Item Name' => 'اسم البند',
	'Quantity' => 'الكمية',
	'List Price' => 'سعر البيع',
	'Image'	=> 'صورة',
	'Purchase Cost' => 'شراء التكلفة',
	'Margin' => 'هامش',
	'Item Comment' => 'تعليق البند',
	'Tax1' => 'ضريبة١',
	'Tax2' => 'ضريبة٢',
	'Tax3' => 'ضريبة٣',
	'Excise Duty' => 'رسوم الاستهلاك',
	'Total' => 'المجموع',
	'Sub Total' => 'المجموع الفرعي',
	'Tax Type' => 'نوع الضريبة',
	'S&H Amount' => 'S&H Amount',
	'Status' => 'الحالة',
	'Vendor Name'=>'اسم المورد',

	'LBL_ADDRESS_INFORMATION' => 'تفاصيل العنوان',
	'LBL_DESCRIPTION_INFORMATION' => 'تفاصيل الوصف',
	'LBL_TERMS_INFORMATION' => 'الشروط و الاحكام',
	'LBL_PRICING_INFORMATION' => 'معلومات التسعير',
	'LBL_RELATED_PRODUCTS' => 'تفاصيل المنتج',
	'LBL_REMINDER_INFORMATION' => 'تفاصيل التذكير',

	'LBL_FOLDER_SAVED' => 'المجلد محفوظ',
	'LBL_FOLDER_EXISTS' => 'المجلد موجود مسبقا',
	'LBL_FOLDER_DELETED' => 'المجلد محذوف',
	'LBL_EDIT_FOLDER' => 'تحرير المجلد',

	'Lead Source' => 'مصدر الزبون المحتمل',
	'Mobile' => 'الهاتف المحمول',

	'Notify Owner' => 'اخطار المالك',

	'State' =>  'الولاية',
	'Po Box' => 'صندوق البريد',
	'Postal Code' => 'الرمز البريدي',

	'Potential Name' => 'اسم الفرصة',
	'Priority'=>'الاولوية',

	'Product Name' => 'اسم المنتج',
	'Rating' => 'التصنيف',

	'Related To'=>'متصل ب',
	'Type' => 'النوع',

	'Reviewed'=>'مراجع',
	'Salutation' => 'تحية',
	'Street' => 'الشارع',
	'Support Start Date' => 'تاريخ بدء الدعم',
	'Support Expiry Date' => 'تاريخ انتهاء الدعم',
	'Sales Start Date'=>'تاريخ بداية المبيعات',
	'Sales End Date'=>'تاريخ انتهاء المبيعات',

	//Dashboard list of widgets translation
	'Open Ticktes' => 'فتح تذاكر',
	'LBL_SELECT_STATUS' => 'حدد الحالة',
	'LBL_BLANK' => '-فارغ-',

	//PageTitle translations
	'LBL_VTIGER_CRM_HONEST_OPEN_SOURCE' => 'vtiger CRM On Demand',

	//Translations used in inventory modules for sopy address
	'SINGLE_Accounts' => 'المنظمات',
	'SINGLE_Contacts' => 'جهات الاتصال',

	//Weekdays in 3 letters translations
	'LBL_Sun' => 'Sun',
	'LBL_Mon' => 'Mon',
	'LBL_Tue' => 'Tue',
	'LBL_Wed' => 'Wed',
	'LBL_Thu' => 'Thu',
	'LBL_Fri' => 'Fri',
	'LBL_Sat' => 'Sat',

	//Months in 3 letters translations
	'LBL_Jan' => 'Jan',
	'LBL_Feb' => 'Feb',
	'LBL_Mar' => 'Mar',
	'LBL_Apr' => 'Apr',
	'LBL_May' => 'May',
	'LBL_Jun' => 'Jun',
	'LBL_Jul' => 'Jul',
	'LBL_Aug' => 'Aug',
	'LBL_Sep' => 'Sep',
	'LBL_Oct' => 'Oct',
	'LBL_Nov' => 'Nov',
	'LBL_Dec' => 'Dec',

	'LBL_CALENDAR_SETTINGS' => 'اعدادات المفكرة',

	//Translations used in inventory modules for address
	'SINGLE_Accounts' => 'منظمة',
	'SINGLE_Contacts' => 'جهة الاتصال',
	'HelpDesk' => 'التذاكر',
	'LBL_TAG_CLOUD' => 'سحابة الكلمات الدلالية',

	'LBL_NO_RECORDS' => 'لايوجد سجلات',
	'LBL_NO_RELATED' => 'لايوجد صلة',
	'LBL_GLOBAL_SEARCH_MAX_MESSAGE' => 'فقط اول ١٠٠ نتيجة من جميع الموديلات سوف تظهر بالاسفل‫.‬ لنتائج محددة للموديل الرجاء حدد الموديل المعني وقم بالبحث',
	'LBL_GLOBAL_SEARCH_MAX_MESSAGE_FOR_MODULE' => 'فقط اول ١٠٠ نتيجة ستظهر بالاسفل‫.‬ الرجاءعمل بحث متقدم اذا اردت نتائج محددة',

	// used in reports detail view
	'LBL_ACTION' => 'نشاط',
	'LBL_NOTE' => 'ملاحظة',
	'LBL_SELECT_OPTION' => 'اختر من القائمة',

	//Module Manager
	'LBL_TOOLTIP' => 'Tooltip Management',
	'LBL_MODULE_SEQUENCE_NUMBERING' => '٪s الصورة الترقيم',
	'LBL_CUSTOM_FIELD_MAPPING' => 'Custom Field Mapping',
	'LBL_WEBFORMS' => 'WebForms',

	//Compose Email Strings
	'SINGLE_Emails' => 'البريد',
	'Emails' => 'الرسائل',
	'LBL_SELECT_EMAIL_IDS' => 'حدد عنوان البريد الالكتروني',
	'LBL_SUBJECT' => 'الموضوع',
	'LBL_ATTACHMENT' => 'المرفقات',
	'LBL_BROWSE_CRM' => 'تصفح CRM',
	'LBL_SEND' => 'ارسال',
	'LBL_SAVE_AS_DRAFT' => 'حفظ كنسخة',
	'LBL_GO_TO_PREVIEW' => 'الذهاب للعرض',
	'LBL_SELECT_EMAIL_TEMPLATE' => 'اختر قالب الرسالة',
	'LBL_COMPOSE_EMAIL' => 'إنشاء الرسالة',
 	'LBL_CC' => 'Cc',
   	'LBL_BCC' => 'Bcc',
   	'LBL_ADD_CC' => 'Add Cc',
   	'LBL_ADD_BCC' => 'Add Bcc',
	'LBL_MAX_UPLOAD_SIZE' => 'الحد الاقصى للتحميل هو',
	'LBL_EXCEEDED' => 'تجاوز',
	'LBL_OPERATION_NOT_PERMITTED' => 'العملية غير مسموح بها',
    'LBL_MERGE' => 'دمج',
	'LBL_FIND_DUPLICATES' => 'البحث عن تكرار',
	'LBL_MERGING_CRITERIA_SELECTION' => 'دمج المعايير المختاره',
	'LBL_AVAILABLE_FIELDS' => 'الحقول المتوفرة',
	'LBL_MERGE_RECORDS_DESCRIPTION' => 'سيتم الاحتفاظ بالسجل الأساسي بعد الدمج. يمكنك تحديد العمود الإبقاء على القيم.
										سيتم حذف السجل الاخر ولكن سيتم دمج المعلومات ذات الصلة.',
	'LBL_MERGE_RECORDS_IN' => 'دمج السجلات في',
	'LBL_FIELDS' => 'حقول',
	'LBL_RECORD' => 'سجل',
	'LBL_NO_DUPLICATED_FOUND' => 'لم يتم العثور على تكرار',
	'LBL_MERGE_SELECT' => 'دمج الاختيارات',
	
	//sbproducts translation
	'LBL_BACK_TO_PRODUCTS' => 'العودة للمنتجات',
	'LBL_CUSTOMIZE_MAIN_MENU' => 'تخصيص القائمة الرئيسية',//TODO REVIEW

	//Comments Field Labels for Workflow
	'Comment' => 'تعليق',
	'Last Comment' => 'آخر تعليق',
	'Last 5 Comments' => 'آخر 5 تعليقات',
	'All Comments' => 'جميع التعليقات',
	
	//Feedback on removing old version
	'LBL_OLD_VERSION_REMOVED_SOON' => 'ملاحظة هامة على نظرة قديم',
	'LBL_FEEDBACK_ON_REMOVING_OLD_VERSION' => 'ونحن سعداء لتبادل والتي تبدو قديمة تكون متاحة حتى فبراير عام 2014. أضفنا الميزات التالية إلى المظهر الجديد مؤخرا <BR> <BR> 1. تقارير محور <BR> 2. المخططات المخصصة <BR> 3. بحث سريع في قوائم <BR> <BR> إذا كان لديك اقتراحات حول نظرة جديدة، يرجى حصة معنا أدناه.',
	'LBL_FEEDBACK_PLACEHOLDER' => 'مشاركة اقتراحاتكم هنا ..',
	'LBL_SUBMIT_FEEDBACK' => 'إرسال الملاحظات',
	'LBL_DONT_SHOW_AGAIN' => 'لا تظهر هذا مرة أخرى',
	'LBL_CONTINUE_TO_OLD_LOOK' => 'تواصل تبدو قديمة',
	
	//For Print Templates
	'Print Templates' => 'قوالب الطباعة',
	'Print' => 'الطباعة / التصدير إلى PDF',
    
     'LBL_TRANSFER_OWNERSHIP' => 'نقل ملكية',
    
    //Products Popup View
    'NOT_A_BUNDLE' => 'لا ربطة',
    'LBL_SUB_PRODUCTS' => 'المنتجات الفرعية',
    'LBL_MARK_AS_HELD' => 'علامة على أنها محتفظ بها',
    'LBL_SMS_MAX_CHARACTERS_ALLOWED' => 'يسمح أقصى 160 حرفا للرسالة نصية',
    'LBL_HIDE_COMPLETED_EVENTS' => 'إخفاء مكتمل الأحداث',
    'LBL_SETUP_WEBFORMS' => 'اعداد نموذج الويب',
    'LBL_SPECIAL_OPTIONS' => 'خيارات خاصة',
    'LBL_PARENT_OWNER' => 'سجل الوالد المالك',
    
    // Recurring Invoice
    'Half-Yearly' => 'نصف سنوي',
    'LBL_FULLSCREEN' => 'الشاشة الكاملة',
    'Email' => 'البريد',
    'LBL_SETUP_WEBFORMS' => 'اعداد نموذج الويب',
    'LBL_MODULE_DISABLED' => '  يتم تعطيل وحدة، ',
    'Organization Name' => 'اسم المنظمة',
    'LBL_WEEK' => 'أسبوع',
    // Convert Lead and Potential
    'LBL_CONVERT_ERROR_TITLE' => 'الموديل معطل',
	'CANNOT_CONVERT' => 'لايمكن التحويل',
	'LBL_FOLLOWING_ARE_POSSIBLE_REASONS' => 'الأسباب المحتملة تشمل ما يلي:',
    'LBL_MANDATORY_FIELDS_ARE_EMPTY' => 'الحقول الالزامية فارغة',
    
    'LBL_ORIGIN' => 'الأصل',
    'SENT' => 'CRM',
    'SAVED' => 'مسودة',
    'MailManager' => 'مدير البريد',
    'MAILSCANNER' => 'تحويل البريد',
	'LBL_SENDER_NAME' => 'اسم المرسل',
    
    'Mobile Call' => 'دعوة المحمول',
	'Related To' => 'ذات الصلة ل',
    
    // Date Conditions
    'LBL_LESS_THAN_DAYS_AGO' => 'أقل من أيام',
    'LBL_MORE_THAN_DAYS_AGO' => 'منذ أكثر من أيام',
    'LBL_IN_LESS_THAN' => 'في أقل من',
    'LBL_IN_MORE_THAN' => 'في أكثر من',
    'LBL_DAYS_AGO' => 'منذ أيام',
    'LBL_DAYS_LATER' => 'أيام في وقت لاحق',
    'LBL_LESS_THAN_HOURS_BEFORE' => 'أقل من ساعة قبل',
    'LBL_LESS_THAN_HOURS_LATER' => 'بعد أقل من ساعة',
    'LBL_MORE_THAN_HOURS_BEFORE' => 'أكثر من ساعة قبل',
    'LBL_MORE_THAN_HOURS_LATER' => 'أكثر من ساعة في وقت لاحق',

	//Related tabs of Products
	'LBL_PRODUCT_BUNDLE' => 'حزمة المنتج',
	'LBL_EDIT_QUANTITY' => 'تحرير الكمية',
	'LBL_ADD_TO_PRODUCTS' => 'إضافة المنتجات',
    'LBL_INTERNAL_COMMENT' => 'تعليق الداخلي',
	'LBL_NOTE_EXISTING_ATTACHMENTS_WILL_BE_REPLACED' => 'ملاحظة: سوف مرفقات الحالية (الصور / الملفات) استبداله',

    //common standard fields
    'Created By' => 'التي أنشأتها',
    
    // SMSNotifier Phone Format Warning
    'LBL_PHONE_FORMAT_WARNING' => 'يرجى التأكد من رقم الهاتف في تنسيق E.164 الدولية',
    'LBL_PHONEFORMAT_WARNING_CONTENT' => 'عدد E.164 التنسيق يمكن أن يكون بحد أقصى خمسة عشر رقما وعادة ما تكون مكتوبة على النحو التالي: [+] [رمز البلد] [رقم المشترك بما في ذلك رمز المنطقة]  على سبيل المثال، لتحويل رقم هاتف الولايات المتحدة (415 599 2671) إلى تنسيق E.164، فإن المرء بحاجة إلى إضافة البادئة ورمز البلد (والذي هو 1) أمام الرقم (+1 415 599 2671 ). في المملكة المتحدة والعديد من البلدان الأخرى على الصعيد الدولي، والاتصال المحلية يتطلب إضافة 0 أمام عدد المشتركين. ومع ذلك، لاستخدام التنسيق E.164، يجب إزالة هذا 0. سيتم تنسيق عدد مثل 020 7183 8750 في المملكة المتحدة و+44 20 7183 8750.',
    'LBL_WARNING' => 'تحذير',
	'LBL_SEND_PDF_FOR_SIGNING' => 'إرسال PDF للتوقيع',
	'LBL_INCLUDE_SIGNATURE_INFO' => 'سيتم إلحاق التوقيع المنصوص عليها في بلدي تفضيلات إلى الجزء السفلي من البريد الإلكتروني',
	'LBL_INCLUDE_SIGNATURE' => 'تشمل التوقيع',
	'LBL_CLICK_HERE'=>'انقر هنا',
    
    // Social Module Strings
    'LBL_TWEETS' => 'تويت',
    'LBL_FAVOURITES' => 'المفضلة',
    'LBL_FOLLOWING' => 'التالي',
    'LBL_FOLLOWERS' => 'أتباع',
    'LBL_VIEW_FULL_PROFILE' => 'عرض كامل الملف',
    'LBL_LOCATION' => 'موقع',
    'LBL_DESCRIPTION' => 'وصف',
    'LBL_JOINED' => 'انضم',
    'LBL_SEARCH_PROFILES_IN_TWITTER' => 'الملامح البحث في تويتر',
    'LBL_CHOOSE_ANOTHER_PROFILE' => 'اختيار وضع آخر',
    'LBL_ADD_TICKET' => 'إضافة تذكرة',
    'LBL_ADD_OPPORTUNITY' => 'إضافة الفرص',
    'LBL_RETWEET' => 'إعادة تغريد',
    'LBL_RETWEETS' => 'Retweets',
    'LBL_UNDO_RETWEET' => 'التراجع ريتويت',
    'LBL_FAVOURITE' => 'المفضل',
    'LBL_UNDO_FAVOURITE' => 'التراجع المفضل',
    'LBL_TWITTER_HANDLER_MSG' => 'لرؤية هذا الاتصال في ملخص الملف الشخصي والتاريخ إضافة معالج تويتر أو البحث ملفاتهم الشخصية باستخدام الرابط أدناه',
    'LBL_ADD_EVENT_OR_TODO' => 'إضافة حدث / العمل',
    'LBL_ADD_TICKET_CONTACT' => 'إضافة تذكرة + الاتصال',
    'LBL_ADD_OPPORTUNITY_CONTACT' => 'إضافة الفرص + الاتصال',
    'LBL_SOCIAL_TWITTER_WIDGET' => 'آخر تويتر',
    'LBL_TWITTER_HANDLER_DETAILS' => 'تويتر معالج تفاصيل',
    'LBL_PRIMARY_TWITTER' => 'تويتر الأساسي',
    'LBL_ADD_TWITTER_HANDLER' => 'إضافة معالج تويتر',
    'LBL_VIEW_TICKET' => 'عرض تذكرة',
    'LBL_VIEW_OPPORTUNITY' => 'عرض الفرص',

    'LBL_SELCT_EMAIL_RECIPIENTS'   => 'تحديد المستلمين البريد الإلكتروني',
	'LBL_REMEMBER_MY_PREF'         => 'تذكر تفضيل بلدي',
	'LBL_RECIPIENT_PREFS'          => 'تفضيلات المتلقي',
	'LBL_EMAIL_RECIPIENT_PREFS'    => 'تفضيلات البريد الإلكتروني المستلم',
	'LBL_ERROR_SAVING_PREF'        => 'خطأ في تفضيلات الادخار. يرجى المحاولة لاحقا!',
	'LBL_NO_PREF_GIVEN'            => 'لا الأفضليات الممنوحة!',
	'LBL_PLEASE_ADD_EMAIL_FIELDS'  => 'الرجاء إضافة حقول البريد الإلكتروني وحاول مرة أخرى',
	'LBL_RECIPIENT_SAVE_MESSAGE'   => 'سيتم التعامل تفضيلات حفظ successful.These كعناوين البريد الإلكتروني المستلم عند إرسال البريد الإلكتروني من هذه الوحدة.',
    

    'LBL_DEFAULT_REPLY_TO' => 'افتراضي رد للرسائل البريد الإلكتروني',
    'outgoing_server_from_email' => 'خادم البريد الصادر من البريد الإلكتروني',
    'hepldesk_support_email' => 'مكتب المساعدة دعم البريد الإلكتروني-معرف',
    'user_primary_email' => 'المستخدم الأساسي البريد الإلكتروني',
    'LBL_DEFAULT_REPLY_TO_INFO' => "هذا الإعداد لا ينطبق إلا على رسائل البريد الإلكتروني مباشرة من CRM. أنها لا تؤثر على رسائل البريد الإلكتروني المرسلة من سير العمل، وحملات البريد الإلكتروني، الخ",
    // Module field to store Source of Record
    'Source' => 'مصدر',

	'VAT' => 'VAT',
	'Sales' => 'مبيعات',
	'Service' => 'خدمة',
	'Pre Tax Total' => 'قبل الضرائب إجمالي',
	'Received' => 'تلقى',
	'Balance' => 'توازن',
	'S&H Amount' => 'شحنة',
	'S&H Percent' => 'الضرائب على رسوم',
	'Tax Region' => 'منطقة الضريبية',
    
    'SINGLE_Potentials' => 'فرصة',
	'SINGLE_HelpDesk' => 'بطاقة دخول',
	'SINGLE_Accounts' => 'منظمة',
	'SINGLE_Contacts' => 'جهة الاتصال',
	'SINGLE_Project' => 'مشروع',
	'LBL_ROLLUP_COMMENTS_INFO' => "وإذا تم تعيين نشمر إلى 'على' يتم عرض التعليقات على السجلات ذات الصلة.
                                   على سبيل المثال، إذا كنت تقوم بعرض تعليقات على سجل المنظمة، إضافة إلى تعليقات ذات الصلة اتصالات والفرص، تذاكر، كما سيتم عرض ... الخ.",
    'LBL_ROLLUP_COMMENTS' => "التراكمي تعليقات",
	'group' => 'مجموعة',
	'individual' => 'فرد',
    //Comment with Attachements
    'LBL_DOWNLOAD_FILE' => 'تحميل الملف',
    'LBL_VIEW_FILE' => 'عرض ملف',
    'LBL_PREVIEW_NOT_AVAILABLE' => 'معاينة غير متوفر',
    'LBL_PREVIEW_SUPPORTED_FILES' => '<b> على <strong> أنواع الملفات المدعومة: </strong> </b> <br> <br> <b> ملفات PDF </b> <br> <b> وملفات نصية - </b> TXT، CSV، ICS<br> <b> وفتح ملفات المستندات - </b> نص وثيقة مفتوحة (ODT)، وثيقة مفتوحة جدول (المواد المستنفدة للأوزون) وعرض المستند المفتوح (ODP) <br> <b> وملفات الوسائط المتعددة - </b> ملفات الصور والصوت والفيديو <br>',
    'Mailing Address' => 'العنوان البريدي',
    'Other Address' => 'غيرها من العناوين',
    'LBL_PREVIOUS' => 'محاكمة حرة تنتهي في ',
    'LBL_NEXT' => 'التالى',
    'Workflows' => 'سير العمل',
    'Primary Twitter' => 'تويتر الأساسي',


	'Engagement Score'             => 'مشاركة نقاط'       ,
	'Click Count'                  => 'انقر فوق عدد'      ,
	// Extensions
    'LBL_SYNC_LOG'                 => 'تزامن دخول',
	'LBL_SYNC_SETTINGS'            => 'إعدادات المزامنة',
	'LBL_SYNC_NOW'                 => 'مزامنة الآن',
	'LBL_DATE'                     => 'تاريخ',
	'LBL_TIME'                     => 'مرة',
	'LBL_SKIPPED'                  => 'تخطي',
	'vt_create'                    => 'vtiger إدارة مكون',
	'vt_update'                    => 'vtiger إدارة تحديث',
	'vt_delete'                    => 'vtiger إدارة محذوفة',
	'vt_skip'                      => 'vtiger إدارة تخطي',
	'app_create'                   => 'مكون تطبيق',
	'app_update'                   => 'تطبيق تحديث',
	'app_delete'                   => ' تطبيق محذوفة',
	'app_skip'                     => 'تطبيق تخطي',
	'LBL_DOWNLOAD_AS_CSV'          => 'تحميل وCSV',
	'LBL_SOURCE_MODULE'            => 'وحدة مصدر',
	'LBL_RECORD_NAME'              => 'اسم سجل',
	'LBL_REASON'                   => 'سبب',
	'LBL_SELECT_MODULES_TO_SYNC'   => 'حدد وحدات لمزامنة',
	'LBL_DATA'                     => 'معطيات',
	'LBL_ENABLE_SYNC'              => 'تمكين مزامنة',
	'LBL_FIELD_MAPPING'            => 'تعيين حقل',
	'LBL_SYNC_DIRECTION'           => 'اتجاه متزامنة',
	'LBL_SYNC_BOTH_WAYS'           => 'مزامنة كلا الاتجاهين',
	'LBL_SAVE_SETTINGS'            => 'حفظ الإعدادات',
    'LBL_CONFIGURE'                => 'تكوين',
	'LBL_VIEW' => 'رأي',
	'LBL_CHANGE_USER' => 'تغيير المستخدم',
    'LBL_SELECT_COLOR' => 'اختر اللون',
    'LBL_CREATION' => 'خلق',
	'LBL_STARRED' => 'تألق',
	'LBL_UNSTARRED' => 'إلغاء تعليم',
    'LBL_EDIT_EMAIL_PREFERENCE_TOOLTIP' => 'تحرير هذه التفضيلات من إعدادات المنسدلة في التفاصيل أو عرض قائمة وحدة نمطية',
	'LBL_SYSTEM' =>'نظام',

  'LBL_LINKED' => 'ربط',
  'LBL_ADDING_NEW' => 'إضافة جديدة',
  'LBL_LESS' => 'أقل',
  'LBL_COMMENT' => 'تعليق',
  'LBL_NOT_STARRED' => 'اتبع',
  'LBL_QUICK_VIEW' => 'عرض سريع',
  'LBL_NOTIFICATION_CENTER' => 'مركز إعلام',
	'LBL_NOTIFICATION' => 'إعلام',
	'LBL_STARRED_RECORD_TO' => '٪ s إلى٪ s',
	'LBL_STARRED_RECORD_UPDATED' => '٪ الصورة المحدثة٪ الصورة',
  'LBL_CONTACT' => 'إدارة الاتصال',
  'LBL_NO_ATTACHMENTS' => 'لا المرفقات',
  'LBL_REARRANGE_DASHBOARD_TABS' => 'إعادة ترتيب علامات التبويب',
  'LBL_DONE' => 'فعلت',
  'LBL_DELETE_DASHBOARD_TAB' => 'حذف علامة التبويب',
  'LBL_DASHBOARD_TAB_ALREADY_EXIST' => 'اسم علامة تبويب موجودة بالفعل',
  'LBL_TABS_LIMIT_EXCEEDED' => 'آسف! لا يمكن إضافة أكثر من 10 علامات',
  'LBL_TODOS' => 'المهام',
  'LBL_VIDEOS' => 'أشرطة الفيديو',
  'LBL_SAME_TAG_EXISTS' => 'مكررة العلامة موجودة',
  'LBL_MAKE_PUBLIC' => 'جعل الجمهور',
  'LBL_CANT_MOVE_FROM_PUBLIC_TO_PRIVATE' => 'لا يمكن قادرا على الانتقال من العام العلامة الخاصة العلامة.',
  'LBL_EDIT_TAG' => 'تحرير العلامة',
  'LBL_NO_TAG_EXISTS' => 'لا الوسم موجود',
  'LBL_HISTORY' => 'نقاط "تاتش بوينتس"',
  'LBL_KEY_FIELD' => 'حقل المفتاح',
  'LBL_NAME_EMAIL' => 'الاسم و البريد الإلكتروني',
  'LBL_IS_REMOVED' => 'إزالة',
  'Activities' => 'الأنشطة',
  'Recycle Bin' => 'سلة المحذوفات',
  'LBL_APPLBL_NONEROVE' => 'الموافقة على',
  'LBL_form' => 'من',
  'LBL_DAY(S' => 'اليوم(s',
  'LBL_HOUR(S' => 'الساعة(s',
  'SINGLE_Users' => 'المستخدم',
  'LBL_MY' => 'بلدي',
  'LBL_TYPE_AND_SEARCH' => 'نوع البحث',
  'LBL_CUSTOMIZE' => 'تخصيص:',
  'LBL_LABELS' => 'التسميات',
  'LBL_WORKFLOWS' => 'مهام سير العمل',
  'LBL_PICKLIST' => 'Picklists',
  'Secondary Email' => 'البريد الإلكتروني الثانوي',
  'Other Email' => 'البريد الإلكتروني الأخرى',
  'Other Phone' => 'الثانوية الهاتف',
  'Phone' => 'الهاتف الرئيسي',
  'Reminder Interval' => 'المنبثقة التذكير الفاصل',
  'Valid Date' => 'تاريخ صحيح',
  'Phone: ' => 'الهاتف: ',
  'Issued Date' => 'صدر التاريخ',
  'Shipping & Handling Charges' => 'الشحن ورسوم المناولة',
  'Shipping & Handling Tax:' => 'الشحن و التعامل مع الضرائب:',
  'Discount' => 'خصم',
  'Net Total' => 'المجموع الصافي',
  'Product Code' => 'رمز المنتج',
  'Customer Name' => 'اسم العميل',
  'Price' => 'السعر',
  'Tax:' => 'الضرائب:',
  'Grand Total:' => 'المجموع:',
  'Fax: ' => 'الفاكس: ',
  'Website: ' => 'الموقع: ',
  'Tax' => 'الضرائب',
  'LBL_ALPHABETS' => 'A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z',
  'Service Contracts' => 'عقود الخدمات',
  'Projects' => 'المشاريع',
  'Sales Order' => 'أوامر المبيعات',
  'Purchase Order' => 'أوامر الشراء',
  'Payments' => 'المدفوعات',
  'List and Campaigns' => 'قائمة والحملات',
  'Project Tasks' => 'المشروع المهام',
  'Project Milestones' => 'معالم المشروع',
  'Labels Editor' => 'تسميات محرر',
  'LBL_IGNORE_EMPTY_VALUES' => 'تجاهل القيم الفارغة',
  'Product Bundles' => 'المنتج حزم',
  'Parent Product' => 'الأصل المنتج',
  'LBL_MANAGE_USERS' => 'إدارة المستخدمين',
  'LBL_SELECT_RELATED_MODULES' => 'حدد وحدات الصلة',
  'LBL_ASSIGNED_TO' => 'تعيين',
  'LBL_LEFT_PANEL_SHOW_HIDE' => 'غادر الفريق إظهار/إخفاء',
  'LBL_PASSWORD_LINK_EXPIRED_OR_INVALID_PASSWORD' => 'كلمة المرور الرابط قد انتهت أو إدخال كلمة مرور غير صالحة',
  'SMSNotifier' => 'SMS منبه',
  'LBL_NO_MORE_RESULTS' => 'لا مزيد من النتائج!',
  'LBL_CLICK_TO_EDIT' => 'انقر فوق تحرير',
  'LBL_SIGNATURE_BLOCK' => 'التوقيع',
  'LBL_BASIC_INFORMATION' => 'المعلومات الأساسية',
  'LBL_PREF_RESET_MESSAGE' => 'المتلقي الخاص بك تفضيلات البريد الإلكتروني تم إعادة تعيين!',
  'LBL_COMPANY_DETAILS' => 'تفاصيل الشركة',
  'COMPANY_LOGO_HELP_TEXT' => 'يرجى تحميل شعار الشركة الخاص بك جميلة. <br>بالإضافة إلى إظهار شعار الشركة الخاصة بك على جهاز CRM<br>
اسم الشركة وعنوان التفاصيل المستخدمة في <br>حملات البريد الالكتروني (مطلوب لتلبية span اللوائح<br>
و في الاقتباس.',
  'COMPANY_LOGO_HELP_TEXT_2' => 'يمكنك تحرير تفاصيل الشركة في وقت لاحق من <br>
\'CRM إعدادات > قوالب > تفاصيل الشركة صفحة',
  'LBL_CHOOSE_PREFERENCES' => 'اختر تفضيلات',
  'PREFERENCES_HELP_TEXT' => 'العملة الأساسية - اختيار العملات الأساسية. إذا كنت تستخدم عدة<br> 
العملات كافة القيم التي يتم تحويلها إلى العملة الأساسية وتخزينها ، <br>
باستخدام معدل التحويل تكوين في CRM.',
  'PREFERENCES_HELP_TEXT_2' => 'التفضيلات الشخصية يمكن تكوينها من قبل كل مستخدم في الفريق.<br>
وتشمل هذه التوقيت, اللغة, موعد تنسيق, تنسيق أرقام.<br>
تنسيق رقم المراجع المستخدمة في العملات وغيرها <br>
عدد الحقول في CRM<br>
يمكنك تعديل التفضيلات الخاصة بك في وقت لاحق من \'اسم المستخدم > تفضيلات \'',
  'LBL_CANNOT_BE_CHANGED_LATER' => 'لا يمكن تغيير وقت لاحق',
  'IMPORT_CONTACTS_GOOGLE_HELP_TEXT' => 'يمكننا جلب جهات الاتصال من جوجل <br> يمكنك أيضا تمكين ثنائية الاتجاه مزامنة أن نحافظ<br>
Vtiger الاتصالات جوجل اتصالات(مجموعة مختارة محدث.<br>
انقر فوق الزر تأذن الحصول على جهات الاتصال من جوجل.',
  'IMPORT_CONTACTS_CSV_HELP_TEXT' => 'يمكنك استيراد جهات الاتصال من ملف CSV.',
  'IMPORT_CONTACTS_CSV_HELP_TEXT2' => 'استيراد الفرص, يؤدي, تذاكر, من فضلك ابحث عن الإجراءات > استيراد زر على أي من
قائمة وجهات النظر.',
  'LBL_DOEST_FIRST_ROW_HEADER' => 'هل الصف الأول في الملف الخاص بك يحتوي على رؤوس الأعمدة?',
  'LBL_SELECT_CSV_FILE' => 'حدد ملف CSV',
  'LBL_START_IMPORTING' => 'تبدأ في استيراد',
  'LBL_PRIMARY' => 'الرئيسية',
  'LBL_GOOGLE_SYNC_INTIATED_MSG' => 'الاستيراد من المقرر, جهات الاتصال الخاصة بك سيتم استيراد قريبا.<br> الانتقال إلى الخطوة التالية لن يعيق الاستيراد.',
  'LBL_IMPORT_SYNC_INTIATED_MSG' => 'الاستيراد قيد التقدم. سوف تتلقى رسالة بريد إلكتروني عند الاستيراد بنجاح.<br> الانتقال إلى الخطوة التالية لن يعيق الاستيراد.',
  'LBL_TELL_US_ABOUT_YOU' => 'تساعدنا بإخبارنا عن شركتك',
  'TELL_US_ABOUT_YOU_HELP_TEXT' => 'ونحن نواصل إدخال تحسينات على CRM <br>
مع العلم مستخدمينا بشكل أفضل سوف تساعدنا على تحديد أولويات التحسينات.',
  'TELL_US_ABOUT_YOU_HELP_TEXT_2' => 'البيانات المقدمة هنا سوف لا يتم الكشف عن أي شخص <Br>
خارج Vtiger.',
  'LBL_INVALID_IMAGE' => 'صورة غير صالح',
  'LBL_IMPORT_CONTACTS' => 'استيراد جهات الاتصال',
  'LBL_FROM_GOOGLE' => 'من جوجل',
  'LBL_FROM_CSV' => 'من ملف CSV',
  'LBL_FINISH' => 'النهاية',
  'LBL_GET_CONTACTS_FROM_GOOGLE' => 'الحصول على جهات الاتصال من جوجل',
  'LBL_PHONE_NUMBER' => 'رقم الهاتف',
  'LBL_NUMBER_OF_EMPLOYEES' => 'عدد الموظفين',
  'LBL_INDUSTRY' => 'صناعة',
  'LBL_HELP_DESK_EMAIL_HELP_TEXT' => 'تذكرة الإخطارات ذات الصلة سيتم إرسالها من عنوان البريد الإلكتروني هذا',
  'LBL_SOCIAL_DETAILS' => 'ارتباط الشبكات الاجتماعية لإيجاد عملاء جدد ، والرد على الاستفسارات',
  'LBL_SOCIAL_AUTHORIZE_HELP' => 'الاتصال مع الشركة حساب تويتر لنشر الرسائل الخاصة بك وتتبع المشاركة',
  'LBL_SOCIAL_AUTHORIZE' => 'الاتصال مع تويتر',
  'LBL_SOCIAL_LINKED' => 'الخاص بك Vtiger مرتبط الآن',
  'LBL_ENTER_KEYWORDS_HELP' => 'Vtiger سوف تفحص تويتر و البحث عن الرسائل مع هذه الكلمات',
  'LBL_ENTER_KEYWORDS' => 'إدخال الكلمات الرئيسية',
  'LBL_ADD_CASE_CONTACT' => 'إضافة Case + الاتصال',
  'LBL_VIEW_CASE' => 'عرض حالة',
  'LBL_CLICK_TO_SELECT_PROFILE' => 'انقر لتحديد ملف التعريف',
  'LBL_CLICK_HERE_TO_SELECT_ALL_RECORDS' => 'تحديد كافة السجلات في هذه الصفحة',
  'LBL_CLICK_HERE_TO_MANAGE_LIST_COLUMNS' => 'انقر هنا لإدارة قائمة الأعمدة',
  'LBL_SHOW_MORE' => 'عرض المزيد',
  'LBL_DISPLAYING_RESULTS' => 'عرض النتائج',
  'LBL_ADD_STAR' => 'إضافة نجمة',
  'LBL_REMOVE_STAR' => 'إزالة نجمة',
  'LBL_UPDATE_LIST' => 'تحديث قائمة',
  'LBL_SHARE_THIS_LIST' => 'حصة قائمة',
  'LBL_ADD_USERS_ROLES' => 'إضافة المستخدمين والأدوار...',
  'LBL_LISTS' => 'قوائم',
  'LBL_SEARCH_FOR_LIST' => 'البحث عن قائمة',
  'LBL_MY_LIST' => 'قائمتي',
  'LBL_SHARED_LIST' => 'المشتركة القائمة',
  'LBL_MERGE_SELECTED_RECORDS' => 'دمج السجلات المحددة',
  'LBL_MATCH_CRITERIA' => 'ازدواجية معايير البحث',
  'LBL_MATCH_FIELDS' => 'تطابق الحقول',
  'LBL_EDIT_CUSTOM' => 'تحرير قائمة',
  'LBL_SHOW_MAP' => 'اعرض الخريطة',
  'LBL_ADD_TAB' => 'إضافة علامة تبويب',
  'LBL_TAB_NAME' => 'علامة التبويب اسم',
  'LBL_SHARED_TAGS_ACCESS' => 'المشتركة العلامات يمكن الوصول إليها من قبل كافة المستخدمين في Vtiger',
  'LBL_GOTO_TAGS' => 'انتقل إلى إعدادات > تفضيلات > العلامات تحرير أو حذف العلامات الخاصة بك',
  'LBL_UNLINK' => 'إلغاء',
  'LBL_SWITCH_TO_OLD' => 'التبديل إلى الإصدار القديم',
  'LBL_CONFIG_COLUMNS' => 'تكوين الأعمدة',
  'LBL_SELECTED_FIELDS' => 'الحقول المحددة',
  'LBL_SEARCH_FIELDS' => 'حقول البحث',
  'ExtensionStore' => 'ملحقات مخزن',
  'LBL_EXTENSIONS' => 'ملحقات',
  'LBL_CREATE_LIST' => 'إنشاء قائمة جديدة',
  'sent' => 'وإرسالها',
  'accepted' => 'قبلت',
  'LBL_RECENT_COMMENTS' => 'التعليقات الأخيرة',
  'LBL_ENGAGEMENT_HISTORY' => 'نقطة اتصال التاريخ',
  'LBL_NO_ENGAGEMENTS_FOUND' => 'لا صلة التواصل',
  'LBL_MARKETING' => 'التسويق',
  'LBL_SALES' => 'المبيعات',
  'LBL_PROJECT' => 'المشاريع',
	'LBL_TOOLS' => 'أدوات',
  'LBL_TAGS' => 'Tags',
  'LBL_SHARE_TAGS' => 'الجمهور العلامات',
  'LBL_SHARE_TAG' => 'حصة العلامة',
  'LBL_TAG_FOR' => 'علامة %s',
  'LBL_CURRENT_TAGS' => 'الحالية العلامات',
  'LBL_CREATE_NEW_TAG' => 'إنشاء علامة جديدة',
  'LBL_ADD_TAG' => 'إضافة علامة',
  'LBL_REMOVE_TAG' => 'إزالة العلامة',
  'LBL_TAG_SEPARATOR_DESC' => 'استخدام الفاصلة لفصل علامات متعددة',
  'LBL_ENTER_TAG_NAME' => 'أدخل اسم العلامة',
  'LBL_ADD_NEW_TAG' => 'إضافة علامة',
  'LBL_SELECT_EXISTING_TAG' => 'اكتب هنا لتحديد القائمة الوسم',
  'LBL_ADD_OR_SELECT_TAG' => 'إضافة/حدد علامة',
  'LBL_SELECT_FROM_AVAIL_TAG' => 'اختر من العلامات المتاحة',
  'LBL_MARKET_PLACE' => 'السوق',
  'EmailTemplates' => 'قوالب البريد الإلكتروني',
  'LBL_BILLING' => 'الفواتير',
  'LBL_ENABLED' => 'تمكين',
  'LBL_CREATE_FILTER' => 'إنشاء عامل تصفية',
  'LBL_IS' => 'هو',
  'LBL_UPLOAD' => 'تحميل',
  'LBL_ATTACH_FILES' => 'إرفاق الملفات',
  'LBL_KEY_FIELDS' => 'المجالات الرئيسية',
  'LBL_ADD_TODO' => 'إضافة مهمة',
  'LBL_VIEW_DETAILS' => 'عرض التفاصيل',
  'LBL_HAPPENED_ON' => 'حدث عن',
  'LBL_HAPPENED' => 'حدث',
  'LBL_TYPE' => 'نوع',
  'LBL_STATUS' => 'مركز',
  'LBL_CUSTOMER' => 'ذات الصلة',
  'LBL_ENGAGEMENTS' => 'نقاط "تاتش بوينتس"',
  'LBL_PLEASE_SELECT_ATLEAST_ONE_OPTION' => 'يرجى اختيار واحد على الأقل الخيار',
  'LBL_GOOGLE_MAP' => 'خريطة جوجل',
  'LBL_KEY_METRICS' => 'المقاييس الرئيسية',
  'LBL_TEMPLATE_NAME' => 'اسم القالب',
  'LBL_MODULE' => 'وحدة',
  'LBL_IS_DEFAULT' => 'القالب الافتراضي',
  'LBL_SELECT_RECORD_FIELD' => 'حدد حقل السجل',
  'LBL_PREVIEW' => 'معاينة',
  'LBL_UNLINKED' => 'غير مرتبطة',
  'LBL_FOLLOW' => 'اتبع',
  'LBL_UNFOLLOW' => 'فولو',
  'Any' => 'أي',
  'LBL_NA' => '-NA-',
  'LBL_DISABLED' => 'تعطيل',
  'LBL_HELP_ANSWERS' => 'إجابات',
  'LBL_HELP_ARTICLES' => 'المواد',
  'LBL_HELP_TOUR' => 'جولة',
  'LBL_NO_HELP_ARTICLE_FOUND' => 'آسف, لا المادة وجدت',
  'LBL_HELP_SEARCH' => 'تعليمات البحث',
  'LBL_HELP_BROWSE_ALL' => 'تصفح جميع',
  'LBL_EXPORT_FILE_NAME' => 'تصدير الملف',
  'LBL_EXTENSION_NOT_ALLOWED_FOR_NONADMIN' => '%s ترجمة يسمح فقط للمستخدمين المشرف',
  'SINGLE_Invoice' => 'الفاتورة',
  'SINGLE_SalesOrder' => 'ترتيب المبيعات',
  'SINGLE_PurchaseOrder' => 'أمر الشراء',
  'SINGLE_Quotes' => 'اقتباس',
	'LBL_POST_YOUR_COMMENT_HERE' => 'أضف تعليقك هنا',
  'LBL_CLICK_TO_CALL' => 'انقر فوق الاتصال',
  'LBL_SHOW_TOTAL_NUMBER_OF_RECORDS' => 'انقر فوق الحصول على مجموع سجل التهم',
  'LBL_GENERAL_FIELDS' => 'المجالات العامة',
  'LBL_ROLL_UP' => 'نشمر',
  'LBL_TOUCH_POINTS' => 'نقاط "تاتش بوينتس"',
  'LBL_EMAIL_SUPPORT'            => 'دعم البريد الإلكتروني', 
  'LBL_NO_ENTITIES_FOUND'        => 'لا %s وجدت'            ,

  'LBL_DAY(S' => 'اليوم(s',
  'LBL_HOUR(S' => 'الساعة(s',
  'LBL_LIST_VIEW' => 'عرض القائمة',
  'LBL_THUMBNAIL_VIEW' => 'عرض الصور المصغرة',
  'LBL_CHART_VIEW' => 'عرض مخطط',


  'LBL_DAYS' => 'اليومs',
  'LBL_HOURS' => 'الساعةs',

  'LBL_SLA_INFORMATION' => 'جيش تحرير السودان من المعلومات',
	'LBL_DELETE_USER_CONFIRMATION' => 'عندما يتم حذف العضو لذلك، سيتم وضع علامة المستخدم بأنه "غير فعال"، ويمكن تعيين أي سجلات جديدة إلى المستخدم، والمستخدم لن يكون قادرا على تسجيل الدخول. هل أنت متأكد أنك تريد حذف؟',

	'LBL_DUPLICATES' => 'التكرارات',
	'LBL_DUPLICATES_DETECTED' => 'تكرار (ق) الكشف عن!',
	'LBL_DUPLICATES_FOUND_MESSAGE' => 'لا يمكن حفظ هذه الصورة٪ منذ مكررة٪ s موجودة في vtiger إدارة مع مطابقة القيم ل٪ s.',
	'LBL_VTIGER_NOTIFICATION' => 'رسالة من: نظام vtiger إدارة الإخطارات',
	'LBL_DUPLICATION_FAILURE_FROM_WORKFLOWS' => 'لا يمكن حفظ التالية٪ s من "٪ الصورة" سير العمل',
	'LBL_DUPLICATION_FAILURE_FROM_WEBFORMS' => 'لا يمكن حفظ التالية٪ s من "٪ ليالي" نموذج ويب',
	'LBL_DUPLICATION_FAILURE_FOR_ADMIN' => 'يمكنك٪ s إلى تعديل قواعد الوقاية مكررة.',
	'LBL_DUPLICATION_FAILURE_FOR_NON_ADMIN' => 'اتصل بالمسؤول لتعديل قواعد مكررة',
	'LBL_DUPLICATE_RECORD_LISTS' => 'مكررة٪ ق (ق):',
);
$jsLanguageStrings = array(
	'JS_EMAIL_SERVER_CONFIGURATION' => 'يرجى تكوين إعدادات ملقم البريد الصادر الخاص بك من صفحة الاعدادات',
	'JS_SMS_SERVER_CONFIGURATION' => 'يرجى تكوين اعدادات الرسائل النصية من صفحة الاعدادات',
	'JS_PLEASE_SELECT_ONE_RECORD' => 'يرجى تحديد سجل واحد على الأقل',

	//Validation Error Message
	'JS_PLEASE_ENTER_VALID_EMAIL_ADDRESS' => 'يرجى إدخال عنوان بريد إلكتروني صالح',
	'JS_CONTAINS_ILLEGAL_CHARACTERS' => 'يحتوي على أحرف غير قانونية',
	'JS_PHONE_NUMBER_LENGTH_EXCEEDED' => 'تجاوز عدد الهاتف طول المحدد',
	'JS_ACCEPT_POSITIVE_NUMBER' => 'يقبل الأرقام الموجبة فقط',
	'JS_VALUE_SHOULD_BE_GREATER_THAN_ZERO' => 'يجب أن تكون القيمة أكبر من الصفر',
    'JS_MASS_EDIT_LIMIT' => 'ويمكن أن يتم عملية تحرير الشامل على 500 أو أقل السجلات في وقت واحد',
	'JS_NUMBER_SHOULD_BE_LESS_THAN_32' => 'يجب أن يكون العدد أقل من ٣٢',
	'JS_PLEASE_ENTER_VALID_DATE' => 'الرجاء إدخال تاريخ صالح',
	'JS_PLEASE_ENTER_VALID_TIME' => 'الرجاء إدخال وقت صالح',
	'JS_INVALID_PAGE_NUMBER' => 'رقم الصفحة غير صحيح',


	'INVALID_NUMBER_OF' => 'عدد غير صالح من',
	'INVALID_NUMBER' => 'عدد غير صالح',
	'JS_LBL_ARE_YOU_SURE_YOU_WANT_TO_DELETE' => 'هل أنت متأكد أنك تريد الحذف؟',

	'OVERWRITE_EXISTING_MSG1' => 'الكتابة فوق العنوان الحالي مع اختيار ',
	'OVERWRITE_EXISTING_MSG2' => 'تفاصيل العنوان؟',
	'SINGLE_Accounts' => 'المنظمات',
	'SINGLE_Contacts' => 'جهات الاتصال',

	'LBL_DELETE_CONFIRMATION' => 'هل أنت متأكد أنك تريد حذف؟', // This is added as duplicate as we need to show different message for different modules. Ex:Accounts has different message
	'LBL_MASS_DELETE_CONFIRMATION' => 'هل أنت متأكد أنك تريد حذف السجلات المحددة؟',
	'JS_LBL_SAVE' => 'حفظ',
	'JS_LBL_CANCEL' => 'الغاء',
	'JS_DUPLICATE_CREATION_CONFIRMATION' => 'اسم المنظمة موجود مسبقا. هل تريد إنشاء سجل مكرر؟',

	'SHOULD_BE_LESS_THAN_TODAY' => 'يجب أن يحدث قبل اليوم',
	'JS_PLEASE_SELECT_ATLEAST_ONE_OPTION' => 'يرجى تحديد خيار واحد على الأقل',
	'JS_SELECT_MODULE' => 'الرجاء تحديد الموديل',
	'JS_PLEASE_SELECT_ATLEAST_ONE_MANDATORY_FIELD' => 'الرجاء اختيار حقل إلزامي واحد على الاقل',
	'JS_SELECT_MODULE' => 'الرجاء اختيار الموديل',
	'JS_PLEASE_ENTER_INTEGER_VALUE' => 'الرجاء إدخال قيمة عددية',
	'JS_PLEASE_ENTER_DECIMAL_VALUE' => 'الرجاء ادخال قيمة عشرية',
	'JS_PLEASE_ENTER_POSITIVE_DECIMAL_VALUE' => 'من فضلك ادخل القيمة العشرية إيجابية',

	'JS_SHOULD_BE_LESS_THAN_CURRENT_DATE' => 'يجب أن تكون أقل من التاريخ الحالي',
	'JS_SHOULD_BE_GREATER_THAN_CURRENT_DATE' => 'ينبغي أن تكون أكبر من التاريخ الحالي',
	'JS_SHOULD_BE_GREATER_THAN_OR_EQUAL_TO' => 'ينبغي أن تكون أكبر من أو يساوي',
    'JS_SHOULD_BE_LESS_THAN_OR_EQUAL_TO' => 'يجب أن تكون أقل من أو يساوي',
	'JS_PERCENTAGE_VALUE_SHOULD_BE_LESS_THAN_100' => 'يجب أن تكون قيمة النسبة المئوية أقل من ١٠٠',
	'JS_ACCEPT_ONLY_NUMBER' => 'يقبل أرقام فقط',
	'JS_THIS_FILE_HAS_ALREADY_BEEN_SELECTED' => 'قد تم بالفعل تحديد هذا الملف',
	'JS_MAX_FILE_UPLOAD_EXCEEDS' => 'الحد الاعلى للملف يتجاوز التحميل',
	'JS_THIS_DOCUMENT_HAS_ALREADY_BEEN_SELECTED' => 'قد تم بالفعل ارفاق هذه الوثيقة',
	'JS_SHOULD_BE_GREATER_THAN_OR_EQUAL_TO' => 'ينبغي أن يكون أكبر من أو يساوي',
    'JS_CURRENT_DATE' => 'التاريخ الحالي',


	//Roles
	'JS_FAILED_TO_SAVE' => 'فشل لحفظ التغييرات على الخادم',

	//Import Translations
	'JS_IMPORT_FILE_CAN_NOT_BE_EMPTY' => 'استيراد ملف لا يمكن أن تكون فارغة',
	'JS_PLEASE_SELECT_ONE_FIELD_FOR_MERGE' => 'حدد حقل واحد على الأقل لمعايير الدمج',
	'JS_MAP_NAME_CAN_NOT_BE_EMPTY' => 'خريطة الاسم لا يمكن أن تكون فارغة',
	'JS_MAP_NAME_ALREADY_EXISTS' => 'خريطة الاسم موجود بالفعل',
	'JS_SELECT_FILE_EXTENSION' => 'الرجاء تحديد الملف مع الملحقات اللاحقة‫:‬',
	'JS_UPLOADED_FILE_SIZE_SHOULD_BE_LESS_THAN' => 'يجب أن يكون حجم الملف المرفوع أقل من',
	'JS_UPLOADED_FILE_SIZE_EXCEEDS' => 'حجم الملف الذي تم تحميله يتجاوز',
	'JS_PLEASE_SPLIT_FILE_AND_IMPORT_AGAIN' => 'يرجى تقسيم الملف إلى ملفات أصغر والاستيراد مرة أخرى.',
	'JS_FIELD_MAPPED_MORE_THAN_ONCE' => 'الحقل تعين اكثر من مرة',
	'JS_MAP_MANDATORY_FIELDS' => 'يرجى تعيين حقول إلزامية',
	'JS_PLEASE_ENTER_SOME_VALUE' => 'الرجاء إدخال قيمة للبحث',

	//Select2 elements validation message
	'JS_YOU_CAN_SELECT_ONLY'=> 'يمكنك اختيار فقط',
	'JS_ITEMS' => 'items',

	'JS_LBL_PERMISSION' => 'تراخيص',
	'JS_CHECK_FILE_INTEGRITY' => 'التحقق من سلامة الملف',
	'JS_DUPLICATE_RECORD' => 'سجل مكرر',

	//advance filter checkbox type condition values
	'JS_IS_ENABLED' => 'تم التفعيل',
	'JS_IS_DISABLED' => 'تم التعطيل',

	'JS_PLEASE_ENTER_SOME_TEXT_FOR_COMMENT' => 'الرجاء إدخال نص للتعليق',
	'JS_LBL_COMMENT_VALUE_CANT_BE_EMPTY' => 'قيمة التعليق لايمكن ان تكون فارغة',
	'JS_REQUIRED_FIELD' => '* هذا الحقل مطلوب',
	'JS_CAN_NOT_REMOVE_DEFAULT_WIDGET' => 'لا يمكن إزالة القطعة الافتراضية',
	'JS_SHOULD_BE_LESS_THAN_CURRENT_DATE' => 'يجب أن تكون أقل من التاريخ الحالي',
	'JS_NO_CREATE_OR_NOT_QUICK_CREATE_ENABLED' => 'لا تنشئ صلاحيات او لم تعطل لانشاء سريع',

	//Image Action
	'LBL_IMAGE_DELETED_SUCCESSFULLY' => 'تم حذف الصورة بنجاح',
	'LBL_IMAGE_NOT_DELETED' => 'لم يتم حذف الصورة',
	'LBL_YES' => 'نعم',
	'LBL_NO' => 'لا',
	'AM' => 'AM',
	'PM' => 'PM',
 	'JS_ERROR' => 'خطآ',
	'JS_INFORMATION' => 'معلومات',
	'JS_DO_NOT_HAVE_AN_EMAIL_ID' => 'لا يملك عنوان بريد الإلكتروني',
	'NONE_OF_THE_FIELD_VALUES_ARE_CHANGED_IN_MASS_EDIT' => 'ولا واحدة من قيم الحقول تم تغيرها في كتلة التعديلات',

	//Notification messages for inventory module
	'JS_PLEASE_SELECT_AN_ACCOUNT_TO_COPY_ADDRESS' => 'الرجاء تحديد المنظمة لنسخ العنوان',
	'JS_PLEASE_SELECT_AN_CONTACT_TO_COPY_ADDRESS' => 'الرجاء تحديد جهات الاتصال لنسخ العنوان',
	'JS_SELECTED_ACCOUNT_DOES_NOT_HAVE_AN_ADDRESS' => 'المنظمة المحددة لا تحتوي على عنوان للنسخ',
	'JS_SELECTED_CONTACT_DOES_NOT_HAVE_AN_ADDRESS' => 'جهة الاتصال لا تحتوي على عنوان للنسخ',
	'JS_PLEASE_ENTER_PRIMARY_EMAIL_VALUE_TO_ENABLE_PORTAL_USER' => 'الرجاء إدخال عنوان البريد الإلكتروني الرئيسي لتمكين مستخدم البوابة',
	'JS_PRIMARY_EMAIL_FIELD_DOES_NOT_EXISTS' => 'حقل البريد الالكتروني غير موجود لتمكين مستخدم البوابة',

	//Tag Cloud validation messages
	'JS_PLEASE_ENTER_A_TAG' => 'الرجاء إدخال العلامة',
	'JS_TAG_NAME_ALREADY_EXIST' => 'اسم العلامة موجود مسبقا',
	'JS_MAX_TAG_LENGTH_EXCEEDS' => 'طول العلامة وصل الحد الاقصى',

	'JS_NO_VIEW_PERMISSION_AFTER_SAVE'=> 'لن يكون لديك صلاحيات لعرض هذا السجل بعد الحفظ. هل ترغب في الاستمرار؟',
	'JS_NO_RECORDS_RELATED_TO_THIS_FILTER' => 'لا يوجد سجلات ذات صلة لهذا اللائحة',

	// Calendar Reminder popup
	'JS_START_DATE_TIME' => 'تاريخ ووقت البداية',
	'JS_END_DATE_TIME' => 'تاريخ ووقت الانتهاء',
	'JS_POSTPONE' => 'تاجيل',
	'JS_MESSAGE' => 'الرسالة',

	'JS_NO_VIEW_PERMISSION_AFTER_SAVE'=> 'لن يكون لديك صلاحيات لعرض هذا السجل بعد الحفظ. هل ترغب في الاستمرار؟',

	//Settings page translations
	'JS_SUCCESSFULLY_PINNED' => 'الاختصار اضيف بنجاح',
	'JS_SUCCESSFULLY_UNPINNED' => 'الاختصار ازيل بنجاح',
	'JS_SHORTCUT_ALREADY_ADDED' => 'هذه الاختصارات مضافة مسبقا',
	'JS_MESSAGE' => 'Message',

	//Module Manager
	'JS_MODULE_ENABLED' => 'الموديل مفعل',
	'JS_MODULE_DISABLED' => 'الموديل معطل',

	//Crom tasks
	'JS_VALUE_SHOULD_NOT_BE_LESS_THAN' => 'تردد اي وظيفة كرون يجب ان لا تقل عن',
	'JS_MINUTES' => 'دقائق',

	//PickList
	'JS_ITEM_RENAMED_SUCCESSFULLY' => 'تم اعادة تسمية البند بنجاح',
	'JS_ITEM_ADDED_SUCCESSFULLY' => 'تم اضافة البند بنجاح',
	'JS_NO_ITEM_SELECTED' => 'لا يوجد بنود مختارة',
	'JS_MORE_THAN_ONE_ITEM_SELECTED' => 'اكثر من بند واحد مختار',
	'JS_ITEMS_DELETED_SUCCESSFULLY' => 'البنود الغيت بنجاح',
	'JS_DUPLICATE_ENTRIES_FOUND_FOR_THE_VALUE' => 'ادخالات مكررة وجدة للقيمة',
	'JS_SELECT_RECORDS_TO_MERGE_FROM_SAME_GROUP' => 'عليك تحديد السجلات التي في نفس المجموعة للدمج',
	'JS_SELECT_ATLEAST_TWO_RECORD_FOR_MERGING' => 'اختر على الاقل سجليين للدمج',
	'JS_ALLOWED_TO_SELECT_MAX_OF_THREE_RECORDS' => 'مسموح لك بتحديد ثلاث سجلات كحد اقصى',
	//Notification message for dashboard widget delete
	'JS_ARE_YOU_SURE_TO_DELETE_WIDGET' => 'هل أنت متأكد من حذف القطعة',
	'JS_DUPLICATE_ENTRIES_FOUND_FOR_THE_VALUE' => 'ادخالات مكررة وجدة للقيمة',
	'JS_SELECT_RECORDS_TO_MERGE_FROM_SAME_GROUP' => 'عليك تحديد السجلات التي في نفس المجموعة للدمج',
	'JS_SELECT_ATLEAST_TWO_RECORD_FOR_MERGING' => 'اختر على الاقل سجليين للدمج',
	'JS_ALLOWED_TO_SELECT_MAX_OF_THREE_RECORDS' => 'مسموح لك بتحديد ثلاث سجلات كحد اقصى',
	'JS_TOTAL_RECORDS' => 'اجمالي السجلات',
	'JS_PAGE_NOT_EXIST' => 'الصفحة غير موجودة',
	'JS_YOU_ARE_IN_PAGE_NUMBER' => 'انت بالصفحة رقم',
	'SINGLE_Vendors' => 'مورد',
	
	//Feedback on removing old version
	'JS_PLEASE_GIVE_YOUR_FEEDBACK' => 'يرجى ملء ردود الفعل الخاصة بك',
	
	//For Print Templates
    'JS_MAX_RECORDS_LIMIT' => 'الحد الأقصى لعدد السجلات للاختيار هي:',
	'JS_NONE' => 'لا شيء',
    
        //For PhoneCalls
        'JS_PBX_CALL_FROM'            =>            'استدعاء من',
        'JS_PBX_INCOMING_CALL'            =>            'مكالمة واردة',
        'JS_PBX_OUTGOING_SUCCESS'            =>            'تلتقط المتلقي ملحق لطلب الرقم',
        'JS_PBX_OUTGOING_FAILURE'            =>            'فشل استدعاء',
        'JS_PBX_FILL_ALL_FIELDS'            =>            'الرجاء تعبئة كافة الحقول',
        'JS_PBX_CAMPAIGN_NAME' => 'Campaign Name',
        'JS_PBX_CAMPAIGN_NUMBER' => 'Campaign Number',
        'JS_MIN_SEARCH_KEY_LENGTH' => 'Search Key should have aleast 3 characters',
        'JS_NO_MATCH' => 'No Matching Records Found',
        'HelpDesk' => 'Tickets',
        'Potentials' => 'Opportunities',
        'JS_PBX_OUTGOING_CALL' => 'Outgoing Call',
        'JS_PBX_CALL_TO' => 'Call To',
        'JS_REQUIRED' => 'Required',
        'JS_PHONE_NUMBER' => 'Phone Number',
        'JS_NO_CREATE_PERMISSION' => 'Call need to be answered before creating record',
        'HelpDesk' => 'Tickets',
        'Potentials' => 'Opportunities',
        //End
    'JS_NO_EDIT_PERMISSION' => 'أنت لا تملك الصلاحيات لتعديل هذا الحدث',
    
        //Google Synchronization
        'SYNC_REMOVED_SUCCESSFULLY' => 'تزامن جوجل إزالة بنجاح.',
        'REMOVE_SYNCHRONIZATION_MESSAGE' => 'سوف النقر على هذا التوثيق إزالة Gmail حالي. انها لن حذف أي السجلات التي يتم مزامنتها مسبقا.',
        'REMOVE_SYNCHRONIZATION' => 'إزالة التزامن',
        'FIELD_MAPPING' => 'رسم الخرائط الميدانية',
        'LBL_SYNC_BUTTON' => 'مزامنة الآن',
        'LBL_SYNCRONIZING' => 'مزامنة ....',
        'LBL_NOT_SYNCRONIZED' => 'هل غير متزامنة بعد',
        'LBL_FIELD_MAPPING' => 'رسم الخرائط الميدانية',
    
        'LBL_RESTORE_CONFIRMATION' => 'لن يتم استعادة السجلات التي كانت مخصصة لهذا المستخدم. هل أنت متأكد من أنك تريد استعادة هذا المستخدم؟',
        'LBL_DELETE_USER_PERMANENT_CONFIRMATION' => 'لا يمكن استعادة بمجرد حذف هذا المستخدم مرة أخرى. هل أنت متأكد أنك تريد حذف هذا المستخدم نهائيا؟',
    
        'LBL_LANGUAGE_LABEL_VALIDATION' => 'قيمة التسمية لا يمكن أن تكون فارغة. يجب عليك إدخال بعض القيمة.',
    	'JS_CHANGES_WILL_BE_LOST' => 'التغييرات الخاصة بك سوف تضيع!',
		'JS_RECORD_DELETED' => 'سجل محذوف',
    'JS_NO_DELETE_PERMISSION' => 'لا توجد صلاحية الحذف',
    'JS_CONFIRM_MARK_AS_HELD' => 'هل أنت متأكد أنك تريد وضع علامة حدث / توضأ كما عقد؟',
    'JS_TODO_MARKED_AS_COMPLETED' => 'كما تميزت تودو مكتمل',
    'JS_EVENT_MARKED_AS_HELD' => 'شهد الحدث كما عقدت',
    'JS_FUTURE_EVENT_CANNOT_BE_MARKED_AS_HELD' => 'الحدث في المستقبل لا يمكن أن تكون علامة على أنها محتفظ بها',
    'JS_PERMISSION_DENIED' => 'تعذر في الوصول',
    'LBL_SMS_MAX_CHARACTERS_ALLOWED' => 'يسمح أقصى 160 حرفا للرسالة نصية',
    'JS_VIEWNAME_ALERT' => 'والحد الأقصى المسموح به 40 حرفا لاسم مرشح',
    'JS_EXCEEDS_MAX_UPLOAD_SIZE' => 'تجاوز الحد الأقصى لحجم التحميل',
    'JS_FUTURE_EVENT_CANNOT_BE_HELD' => 'لا يمكن عقد لمستقبل',
    'LBL_WARNING' => 'تحذير',
    'DELETE_USER_PERMANENT_WARNING' => 'وحذف مستخدم بشكل دائم نقل جميع السجلات بما في ذلك التعليقات والتاريخ لمستخدم جديد.',
    'JS_CLOSE' => 'قريب',
    'JS_DECIMAL_SEPARATOR_AND_GROUPING_SEPARATOR_CANT_BE_SAME' => 'العشري المفرق المفرق والتجمع لا يمكن أن يكون نفس',
    // For Line Iteam Currency Symbol select while Import
    'JS_CURRENCY_TOOLTIP_CONTENT_TITLE' => 'خط وحدات العملة',
    'JS_CURRENCY_TOOLTIP_CONTENT_MESSAGE' => 'لاستيراد قيم العملات في بنود، وسوف vtiger إدارة استخدام هذا الإعداد لتحديد العملة. أي قيم العملات خارج بنود الجداول، Assumel أن يكون من المفضل العملة في المستخدمين ( مختارة في بلدي تفضيلات )',    
	'LBL_CANT_SELECT_CONTACT_FROM_LEADS' => 'لايمكن تحديد جهات الاتصال ذات الصلة للزبون المحتمل',
    'JS_FILE_NAME' => 'اسم الملف',
    'JS_EXTERNAL_FILE_URL' => 'رابط الملف',
    'JS_PLEASE_SELECT_A_FILE' => 'الرجاء اختيار ملف',
    
    // SMSNotifier Phone Format Warning
    'JS_PHONEFORMAT_ERROR' => 'يرجى التحقق من رقم الهاتف في تنسيق E.164 INTERNATONAL مع بادئة ورمز البلد تحويلة +1 415 2671 599',
    
    // Lead and Potential Mapping Fields
    'JS_NONE' => 'None',
	'JS_IS_ALREADY_BEEN_MAPPED' => 'is already been mapped',
	'JS_CANT_MAP' => 'Cant map',
	'JS_WITH' => 'with',
	'JS_MAPPING_DELETED_SUCCESSFULLY' => 'Mapping Deleted Successfully',
	
	//JS Field Type Translation
	'JS_phone' => 'Phone',
	'JS_picklist' => 'Pick List',
	'JS_email' => 'Email',
	'JS_text' => 'String',
	'JS_currency' => 'Currency',
	'JS_multiSelectCombo' => 'Multi-Select Combo Box',
	'JS_time' => 'Time',
	'JS_textArea' => 'Text Area',
	'JS_url' => 'Url',
	'JS_string' => 'String',
	'JS_checkBox' => 'Check Box',
	'JS_date' => 'Date',
	'JS_decimal' => 'Decimal',
	'JS_percent' => 'Percent',
	'JS_skype' => 'Skype',
	'JS_None' => 'None',
    'JS_double' => 'عشري',
    'JS_reference' => 'مرجع',
	'JS_image' => 'صورة',
    
     // AutoFill Overwriting message
    'JS_OVERWRITE_AUTOFILL_MSG1' => 'هل ترغب في الكتابة القائمة',
    'JS_OVERWRITE_AUTOFILL_MSG2' => 'مع نخبة من',
    'JS_PRINT' => 'طباعة',
    'JS_SAVE_AS_IMAGE' => 'كما حفظ صورة',
    
     //Demo Data Module Translatios
    'JS_ADD_DEMO_DATA_CONFIRMATION'=> 'هل أنت متأكد من أنك تريد إضافة سجلات التجريبي لكافة الوحدات النمطية؟',
    'JS_ADD_DEMO_DATA_INFO'=> 'يمكن حذف السجلات التجريبي من خلال النقر على زر "مسح تجريبي البيانات".',
    'JS_CLEAR_DEMO_DATA_CONFIRMATION'=> 'هل أنت متأكد من أنك تريد مسح البيانات التجريبي في كافة الوحدات النمطية؟',
    'JS_CLEAR_DEMO_DATA_INFO'=> 'يمكن إضافة سجلات التجريبي بالنقر على "أضف تجريبي البيانات" الزر.',
    'JS_DEMO_DATA_GETTING_POPULATED'=> 'يتم إضافة البيانات التجريبي، الرجاء الانتظار...',
    'JS_DEMO_DATA_GETTING_CLEARED'=> 'يتم مسح البيانات التجريبي، الرجاء الانتظار...',
    'JS_DEMO_DATA_ADDED' => 'إضافة البيانات التجريبي لجميع الوحدات.',
    'JS_DEMO_DATA_CLEARED' => 'حذف البيانات من جميع وحدات التجريبي.',
    'JS_HOME_DASH_BOARD_CLEAR_INFO'=>'ملاحظة: يمكنك إعادة تمكين عرض البيانات من', 
    'JS_SETTINGS_PATH'=>'إعدادات> إعدادات أخرى> محرر تكوين.',
    'JS_DIRECTORY_IS_EMPTY' => 'الدليل فارغة',
	'JS_PLEASE_SELECT_AN_RELATED_TO_COPY_ADDRESS' => 'يرجى تحديد وحدة الرصاص / الاتصال لنسخ عنوان ',	
	'SINGLE_Leads' => 'الإعدادات المحفوظة',
	'JS_SELECTED_LEAD_DOES_NOT_HAVE_AN_ADDRESS' => 'لا يحتوي على الرصاص اختيار عنوان لنسخ',
    'JS_INVALID_EMAILS' => 'رسائل البريد الإلكتروني غير صالحة',
    'JS_INTERNAL_COMMENT' => 'تعليق الداخلي',
    'JS_INTERNAL_COMMENT_INFO' => 'سوف فقط أن ينظر إلى تعليق من قبل المستخدمين CRM، إذا تم تمكين خانة التعليق الداخلية. لإعلام العملاء (من خلال سير العمل شكلي أو بوابة العملاء) ترك هذا الاختيار تعطيل',
    'JS_NO_LINE_ITEM' =>'بنود لا يمكن أن تكون فارغة.',

	//More currencies message
	'JS_BASE_CURRENCY_CHANGED_TO_DISABLE_CURRENCY' => 'Base Currency has to be changed to disable ',
	'JS_INTERNAL_COMMENT' => 'تعليق الداخلي',
    'JS_INTERNAL_COMMENT_INFO' => 'سوف فقط أن ينظر إلى تعليق من قبل المستخدمين CRM، إذا تم تمكين خانة التعليق الداخلية. لإعلام العملاء (من خلال سير العمل شكلي أو بوابة العملاء) ترك هذا الاختيار تعطيل',

	'JS_NO_TAXES_EXISTS' => 'لا توجد ضرائب',
	'JS_CONFIRM_TAXES_AND_CHARGES_REPLACE' => 'هل تريد تحديث الضرائب ورسوم القيم المقابلة لمنطقة المختارة؟',
    'JS_PRINTTEMPLATEMODULE_DISABLED' => 'تم تعطيل حدة PrintTemplates. لا يمكن تنفيذ العملية',
    'JS_SENT_FOR_SIGNATURE' => 'أرسلت للتوقيع',
    'JS_FAILED_TO_SEND_FOR_SIGNATURE' => 'فشل في إرسال لتوقيع اتصال',
    
	// Cron
    'JS_NONE_OF_THE_VALUES_ARE_CHANGED' => 'يتم تغيير أي من القيم',
	
	//google
	'JS_SUITABLE_VTIGER_FIELD_NOT_AVAILABLE_FOR_MAPPING' => 'الحقل vtiger إدارة مناسبة لا يتوفر لرسم الخرائط',
    'JS_SAVED_SUCCESSFULLY' => 'الإعدادات المحفوظة بنجاح',
    'phone' => 'هاتف',
    'email' => 'البريد الإلكتروني',
    'url' => 'رابط',
    'home' => 'منزل',
    'work' => 'عمل',
    'custom' => 'عرف',
    'mobile' => 'متحرك',
    'main' => 'رئيسي',
    'work_fax' => 'فاكس',
    'home_fax' => 'الصفحة الرئيسية فاكس',
    'pager' => 'بيجر',
    'profile' => 'الملف الشخصي',
    'blog' => 'بلوق',
    'home-page' => 'الصفحة الرئيسية',
    'address' => 'عنوان',
    'JS_REMOVE_SYNC_CONFIRMATION' => 'إزالة تزامن سيزيل فقط المصادقة الحالية، وسوف يتم حذف سجلات متزامنة. إذا كنت مزامنة مع حساب Google نفسه مرة أخرى، سيتم إنشاء سجلات مكررة. هل أنت متأكد أنك تريد إزالة التزامن؟',
    
    // Social Module Strings
    'JS_PLEASE_WAIT' => 'يرجى الانتظار ...',
    'JS_SOCIAL_FIELD_ERROR' => 'مطلوب الحقل',
    // Twitter Specific
    'JS_ADD_FAVOURITE_SUCCESS_MSG' => 'التغريدة أضيفت إلى قائمة المفضلة بنجاح',
    'JS_UNDO_FAVOURITE_SUCCESS_MSG' => 'التغريدة إزالتها من قائمة المفضلة بنجاح',
    'JS_UNDO_RETWEET_SUCCESS_MSG' => 'UndoRetweet بنجاح',
    'JS_STATUS_UPDATE_SUCCESS_MSG' => 'تحديث بنجاح',
    'JS_TWEET_DELETE_MSG' => 'حالة محذوف بنجاح',
    'JS_INVALID_TWITTER_HANDLER_NAME' => 'اسم تويتر معالج غير صالح',
    'JS_RELATION_ADDED_SUCESSFULLY' => 'واضاف علاقة بنجاح',
    'JS_FAILED_TO_ADD_RELATION' => 'فشل لإضافة العلاقات',
    'JS_SOCIAL_POST_DELETE_CONFIRMATION' => 'هل أنت متأكد أنك تريد حذف؟',
    'JS_EVENT_OR_TODO_ADDED_SUCCESS_MSG' => 'حدث / وأضاف تودو بنجاح',
    'JS_LEAD_ADDED_SUCCESS_MSG' => 'وأضاف الرصاص بنجاح',
    'JS_OPPORTUNITY_ADDED_SUCESS_MSG' => 'وأضافت فرصة بنجاح',
    'JS_TICKET_ADDED_SUCESS_MSG' => 'وأضاف تذكرة بنجاح',
	'JS_SELECT_OPTION' => 'اختر من القائمة',
    
    'JS_REMOVE_SYNC_CONFIRMATION' => 'إزالة تزامن سيزيل فقط المصادقة الحالية، وسوف يتم حذف سجلات متزامنة. إذا كنت مزامنة مع حساب Google نفسه مرة أخرى، سيتم إنشاء سجلات مكررة. هل أنت متأكد أنك تريد إزالة التزامن؟',
    'JS_PASSWORD_MISMATCH_ERROR' => 'يرجى إعادة إدخال كلمة السر. "كلمة السر الجديدة" و "كلمة المرور تأكيد" عدم تطابق القيم.',
	'JS_COMMA_NOT_ALLOWED_USERS' => 'لا يسمح فاصلة (،) في الاسم الأول واسم العائلة',
    'JS_LBL_GETTING_RECIPIENT_PREFS' => 'الحصول على تفضيلات المتلقي ..',
	'JS_LBL_SAVING_PREFERENCES'    => 'إنقاذ تفضيلات ..',

    //Office365
    'LBL_REMOVE_SYNC_CONFIRMATION' => 'يزيل الترخيص للاتصالات، والتقويمات، ورسائل البريد الإلكتروني. هل أنت متأكد أنك تريد إزالة المزامنة؟',
    'OFFICE365_SYNC_REMOVED_SUCCESSFULLY' => 'Office365 متزامنة إزالة بنجاح',
    'OFFICE365_REMOVE_SYNCHRONIZATION_MESSAGE' => 'النقر على هذا التوثيق إزالة Office365 القائمة. وسوف يتم حذف أي السجلات التي يتم مزامنتها بالفعل. انها لن إلغاء تسجيل التطبيق vtiger إدارة منك office365 الاعتبار، إلى إلغاء زيارة https://myapps.microsoft.com/',
    
    'JS_LOADING_COMMENTS' => 'جلب تعليقات ...',
    'Payment Failure!' => 'الفشل الدفع!', 
    'We could not process the payment for your last invoice. Please update payment info to continue using the service without disruption.' => 'لم نتمكن من معالجة عملية الدفع للمشاركة الفاتورة. يرجى تحديث معلومات الدفع لمواصلة استخدام الخدمة دون انقطاع.',
    'For assistance, please send email to' => 'للحصول على المساعدة، الرجاء ارسال بريد الكتروني',
    'JS_MAX_ALLOWED_CHARACTERS' => 'الأحرف المسموح بها الحد الأقصى هو',

	'JS_DEFAULT_ENABLED' => 'تمكين الافتراضي',
	'JS_DEFAULT_DISABLED' => 'الافتراضي تعطيل',

  'JS_PLEASE_ENTER_VALID_VALUE' => 'الرجاء إدخال قيمة صالحة',
  'JS_PLEASE_ENTER_VALID_TAG_NAME' => 'يرجى إدخال اسم العلامة صالح',
  'JS_TAG_SAVED_SUCCESSFULLY' => 'العلامة حفظها بنجاح',
  'JS_SUBJECT_VALUE_CANT_BE_EMPTY' => 'الموضوع لا يمكن أن تكون القيمة فارغة',
  'JS_PERCENTAGE_SHOULD_BE_LESS_THAN_100' => 'النسبة المئوية يجب أن تكون أقل من 100',
  'LBL_DELETE_USER_CONFIRMATION' => 'عندما يقوم المستخدم حذف مستخدم سيتم وضع علامة "غير فعال" و لا سجلات جديدة يمكن تعيينه إلى المستخدم و المستخدم لن يكون قادرا على تسجيل الدخول. الفواتير سوف تتوقف عن هذا المستخدم.إذا كنت بحاجة إلى تنشيط حذف المستخدم, سوف تحتاج إلى إرسال بريد إلكتروني إلى support@vtiger.com.Are أنت متأكد من أنك تريد حذف ؟ ',
  'JS_ARE_YOU_SURE_TO_DELETE_DASHBOARDTAB' => 'هل أنت متأكد من حذف علامة التبويب',
  'JS_TABS_LIMIT_EXCEEDED' => 'آسف! لا يمكن إضافة أكثر من 10 علامات',
  'JS_PLEASE_ENABLE_BASE_CURRENCY_FOR_PRODUCT' => 'يرجى تمكين العملة الأساسية عن المنتج',
  'JS_PLEASE_SELECT_BASE_CURRENCY_FOR_PRODUCT' => 'يرجى تحديد العملة الأساسية عن المنتج',
  'JS_RECORDS_ARE_GETTING_DELETED' => 'سجلات الحصول على حذفها',
  'JS_RECORD_GETTING_DELETED' => 'سجل الحصول على حذفها',
  'JS_NO_RESULTS_FOUND' => 'لا توجد نتائج',
  'JS_RECORDS TRANSFERRED SUCCESSFULLY' => 'الوثائق الملكية تم tranferred بنجاح',
  'LBL_SEARCHING' => 'البحث في ',
  'JS_RECORDS_TRANSFERRED_SUCCESSFULLY' => 'الوثائق الملكية نقله بنجاح.',
  'JS_USER_DELETED_SUCCESSFULLY' => 'المستخدم حذف بنجاح.',
  'JS_USER_EXISTS' => 'المستخدم موجود مسبقا',
  'JS_REENTER_PASSWORDS' => 'المستأجر كلمات المرور',
  'LBL_SIGN_IN_AS_USER' => 'تسجيل الدخول كمستخدم آخر سيتم إنهاء الدورة الحالية. هل انت متأكد تريد الاستمرار ؟ ',
  'JS_TRY_LATER' => 'يرجى المحاولة في وقت لاحق!',
  'JS_integer' => 'عدد صحيح',
  'JS_CANCEL_SUBSCRIPTION_CONFIRMATION' => 'هل أنت متأكد من أنك تريد إلغاء الاشتراك ؟ ',
  'JS_PLAN_CHANGED_SUCCESSFULLY' => 'خطة جديدة تفعيله بنجاح.',
  'JS_SUBSCRIPTION_CANCELLED_SUCCESSFULLY' => 'الاشتراك إلغاء بنجاح.',
  'JS_REACTIVATED_SUCCESSFULLY' => 'Vtiger تفعيل الاشتراك بنجاح',
  'JS_PAYMENTMETHOD_ADDED_SUCCESSFULLY' => 'شكرا على الاشتراك. طريقة الدفع المضافة بنجاح',
  'JS_EXCLUSIVE_MONTH_PLAN_TO_UPGRADE_CONFIRMATION' => 'حصريا خطة الاشتراك الشهري (12 دولارا لكل مستخدم. حسابك سوف يتم احتساب الفرق في ثمن الجزء المتبقي من فترة الفاتورة الحالية. يرجى تأكيد ما إذا كنت ترغب في المتابعة الحصرية الخطة الشهرية.',
  'JS_ULTIMATE_MONTH_PLAN_TO_UPGRADE_CONFIRMATION' => 'في نهاية المطاف خطة الاشتراك الشهري (36 دولارا لكل مستخدم. حسابك سوف يتم احتساب الفرق في ثمن الجزء المتبقي من فترة الفاتورة الحالية. يرجى تأكيد ما إذا كنت ترغب في المضي قدما في نهاية المطاف خطة شهرية.',
  'JS_SALESPREMIUM_MONTH_PLAN_TO_UPGRADE_CONFIRMATION' => 'المبيعات المميزة تمتع بالاستفادة من خطة الاشتراك الشهري (24 دولار لكل مستخدم. حسابك سوف يتم احتساب الفرق في ثمن الجزء المتبقي من فترة الفاتورة الحالية. يرجى تأكيد ما إذا كنت ترغب في الشروع في المبيعات أقساط شهرية.',
  'JS_SUPPORT_MONTH_PLAN_TO_UPGRADE_CONFIRMATION' => 'دعم خطة الاشتراك الشهري (12 دولارا لكل مستخدم. حسابك سوف يتم احتساب الفرق في ثمن الجزء المتبقي من فترة الفاتورة الحالية. يرجى تأكيد ما إذا كنت ترغب في المضي قدما في خطة الدعم الشهري.',
  'JS_SALES_MONTH_PLAN_TO_UPGRADE_CONFIRMATION' => 'خطة المبيعات الشهرية رسوم الاشتراك (12 دولارا لكل مستخدم. حسابك سوف يتم احتساب الفرق في ثمن الجزء المتبقي من فترة الفاتورة الحالية. يرجى تأكيد ما إذا كنت ترغب في المضي قدما في خطة المبيعات الشهرية.',
  'JS_CONTACT_MONTH_PLAN_TO_UPGRADE_CONFIRMATION' => 'إدارة الاتصال لخطة رسم الاشتراك الشهري (9 دولارات لكل مستخدم. حسابك سوف يتم احتساب الفرق في ثمن الجزء المتبقي من فترة الفاتورة الحالية. يرجى تأكيد ما إذا كنت ترغب في المضي قدما إلى إدارة الاتصال الخطة الشهرية.',
  'JS_EXCLUSIVE_ANNUAL_PLAN_TO_UPGRADE_CONFIRMATION' => 'حصريا خطة رسم الاشتراك السنوي (132 دولارا لكل مستخدم. حسابك سوف يتم احتساب الفرق في ثمن الجزء المتبقي من فترة الفاتورة الحالية. يرجى تأكيد ما إذا كنت ترغب في المتابعة الحصرية الخطة السنوية.',
  'JS_ULTIMATE_ANNUAL_PLAN_TO_UPGRADE_CONFIRMATION' => 'في نهاية المطاف خطة رسم الاشتراك السنوي (360 دولار لكل مستخدم. حسابك سوف يتم احتساب الفرق في ثمن الجزء المتبقي من فترة الفاتورة الحالية. يرجى تأكيد ما إذا كنت ترغب في المضي قدما في نهاية المطاف إلى الخطة السنوية.',
  'JS_SALESPREMIUM_ANNUAL_PLAN_TO_UPGRADE_CONFIRMATION' => 'المبيعات خطة قسط رسوم الاشتراك السنوي (240 دولارا لكل مستخدم. حسابك سوف يتم احتساب الفرق في ثمن الجزء المتبقي من فترة الفاتورة الحالية. يرجى تأكيد ما إذا كنت ترغب في الشروع في المبيعات المميزة تمتع بالاستفادة من الخطة السنوية.',
  'JS_SUPPORT_ANNUAL_PLAN_TO_UPGRADE_CONFIRMATION' => 'خطة الدعم رسم الاشتراك السنوي (120 دولار لكل مستخدم. حسابك سوف يتم احتساب الفرق في ثمن الجزء المتبقي من فترة الفاتورة الحالية. يرجى تأكيد ما إذا كنت ترغب في المضي قدما في دعم الخطة السنوية.',
  'JS_SALES_ANNUAL_PLAN_TO_UPGRADE_CONFIRMATION' => 'خطة المبيعات السنوية رسوم الاشتراك (120 دولار لكل مستخدم. حسابك سوف يتم احتساب الفرق في ثمن الجزء المتبقي من فترة الفاتورة الحالية. يرجى تأكيد ما إذا كنت ترغب في المضي قدما في خطة المبيعات السنوية.',
  'JS_CONTACT_ANNUAL_PLAN_TO_UPGRADE_CONFIRMATION' => 'إدارة الاتصال لخطة رسم الاشتراك الشهري (99 دولارا لكل مستخدم. حسابك سوف يتم احتساب الفرق في ثمن الجزء المتبقي من فترة الفاتورة الحالية. يرجى تأكيد ما إذا كنت ترغب في الشروع في الاتصال خطة الإدارة السنوية.',
  'JS_CASE_ADDED_SUCESS_MSG' => 'حالة إضافتها بنجاح',
  'JS_ENTERED_CURRENT_USERNAME_MSG' => 'دخلت اسم المستخدم الحالي. يرجى إدخال اسم المستخدم الجديد.',
  'JS_LOADING_PLEASE_WAIT' => '... جاري التحميل يرجى الانتظار..',
  'JS_SAVING_PLEASE_WAIT' => 'إنقاذ.. يرجى الانتظار..',
  'JS_DUPLICATE_EMAILS_PLEASE_CHECK' => 'عناوين البريد الإلكتروني مكررة. يرجى التحقق من',
  'JS_ALERT' => 'تنبيه',
  'JS_SUCCESS' => 'النجاح',
  'JS_REMOVE_MASS_TAG_WARNING' => 'هل أنت متأكد من أنك تريد إزالة %s العلامة على السجلات المحددة',
  'JS_VIEW_ALREADY_EXISTS' => 'عرض موجود بالفعل',
  'JS_PLEASE_ENTER_NUMBER_IN_RANGE' => 'الرجاء إدخال قيمة في نطاق',
  'JS_UPLOAD' => 'تحميل',
  'JS_TODO_ADDED_SUCCESS_MSG' => 'المهمة المضافة بنجاح',
  'JS_EVENT_ADDED_SUCCESS_MSG' => 'الحدث إضافة بنجاح',
  'JS_ACTIVE' => 'نشط',
  'JS_SNOOZED' => 'Snoozed',
  'JS_INVALID_URL' => 'URL غير صالح',
  'JS_ARE_YOU_SURE_YOU_WANT_TO_DELETE' => 'هل أنت متأكد من أنك تريد حذف ؟ ',
  'JS_TAB_LABEL_EXCEEDS_CHARS' => 'علامة التبويب التسمية طول ينبغي أن يكون أقل من %s الشخصيات',
  'JS_STARRED' => 'تألق',
  'JS_NOT_STARRED' => 'لا يقوم ببطولته',
  'JS_NO_TAG_EXISTS' => 'لا الوسم موجود',
  'JS_HELP_AND_SUPPORT' => 'المساعدة و الدعم',
  'JS_WHAT_DO_YOU_NEED_HELP_WITH' => 'ماذا هل تحتاج إلى مساعدة ؟ ',
  'JS_SUBMIT' => 'يقدم',
  'JS_ADD_MAX_15_ITEMS' => 'يمكنك فقط إضافة 15 البنود',
  'SINGLE_SLA' => 'جيش تحرير السودان',
  'JS_EDIT_FIELDS' => '%s الحقول و تخطيط',
  'JS_MORE_VTIGER' => 'هناك المزيد من الوثائق إلى أن تكون متزامنة في vtiger',
  'JS_MORE_GOOGLE' => 'هناك المزيد من الوثائق إلى أن تكون متزامنة في جوجل',
  'JS_MORE_OFFICE365' => 'هناك المزيد من الوثائق إلى أن تكون متزامنة في Office365',
  'JS_TOKEN_EXPIRED' => 'Office365 مصادقة قد انتهت. انقر على تسجيل الدخول مع Office365 زر إعادة الترخيص.',
  'JS_WISH_TO_PROCEED' => 'هل أنت متأكد من أنك تريد المتابعة ؟ ',
  'JS_SWITCH_TO_OLD_LOOK_CONFIRMATION_MESSAGE' => 'بعض الميزات, بما في ذلك الإخطارات picklist الألوان اتبع سجل غير متوفرة في النسخة القديمة. يمكنك التبديل إلى الإصدار الجديد عن طريق اختيار الإصدار الجديد من أعلى يمين القائمة.',
  'JS_PROCEED_OLD_VERSION' => 'انتقل إلى الإصدار القديم',
  'JS_STAY_WITH_NEW_VERSION' => 'البقاء مع الإصدار الجديد',
  'JS_AGO' => 'مضت',
  'JS_FROM_NOW' => 'من الآن',
  'JS_LESSTHAN_A_MINUTE' => 'أقل من دقيقة',
  'JS_A_MINUTE' => 'دقيقة',
  'JS_AN_HOUR' => 'ساعة',
  'JS_HOURS' => 'ساعات',
  'JS_A_DAY' => 'اليوم',
  'JS_DAYS' => 'أيام',
  'JS_A_MONTH' => 'شهر',
  'JS_MONTHS' => 'أشهر',
  'JS_A_YEAR' => 'سنة',
  'JS_YEARS' => 'سنوات',
  'JS_TODAY' => 'اليوم',
  'JS_TOMORROW' => 'غدا',
  'JS_YESTERDAY' => 'أمس',
  'JS_CREATE_TASK' => 'إنشاء مهمة',


  'JS_SUPPORTPREMIUM_MONTH_PLAN_TO_UPGRADE_CONFIRMATION' => 'دعم قسط خطة الاشتراك الشهري (24 دولار لكل مستخدم. حسابك سوف يتم احتساب الفرق في ثمن الجزء المتبقي من فترة الفاتورة الحالية. يرجى تأكيد ما إذا كنت ترغب في المضي قدما في دعم أقساط شهرية.',
  'JS_SUPPORTPREMIUM_ANNUAL_PLAN_TO_UPGRADE_CONFIRMATION' => 'دعم أقساط رسوم الاشتراك السنوي (240 دولارا لكل مستخدم. حسابك سوف يتم احتساب الفرق في ثمن الجزء المتبقي من فترة الفاتورة الحالية. يرجى تأكيد ما إذا كنت ترغب في المضي قدما في دعم المميزة تمتع بالاستفادة من الخطة السنوية.',


  'JS_MENTION_ATLEAST_ONE_USER' => 'يذكر مستخدم واحد على الأقل',
  'JS_LOADING' => 'تحميل...',
	
	'JS_UPLOAD_SUCCESSFUL' => 'الملف الذي تم تحميله بنجاح',
    'JS_UPLOAD_FAILED' => 'تحميل ملف فشل',

	'JS_DUPLICATES_DETECTED' => 'تكرار (ق) الكشف عن!',
	'JS_PASSWORD_MISMATCH_ERROR' => 'يرجى إعادة إدخال كلمة السر. "كلمة السر الجديدة" و "كلمة السر تأكيد" عدم تطابق القيم.',
	'JS_LIST_DELETE_CONFIRMATION' => 'هل أنت متأكد أنك تريد حذف؟',
	'JS_WIDGET_RESIZING_WAIT_MSG' => 'سيتم تحميل محتويات القطعة بعد تغيير الحجم.',
);
